Class: Aws::Inspector2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Inspector2::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-inspector2/client.rb
Overview
An API client for Inspector2. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Inspector2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_member(params = {}) ⇒ Types::AssociateMemberResponse
Associates an Amazon Web Services account with an Amazon Inspector delegated administrator.
-
#batch_associate_code_security_scan_configuration(params = {}) ⇒ Types::BatchAssociateCodeSecurityScanConfigurationResponse
Associates multiple code repositories with an Amazon Inspector code security scan configuration.
-
#batch_disassociate_code_security_scan_configuration(params = {}) ⇒ Types::BatchDisassociateCodeSecurityScanConfigurationResponse
Disassociates multiple code repositories from an Amazon Inspector code security scan configuration.
-
#batch_get_account_status(params = {}) ⇒ Types::BatchGetAccountStatusResponse
Retrieves the Amazon Inspector status of multiple Amazon Web Services accounts within your environment.
-
#batch_get_code_snippet(params = {}) ⇒ Types::BatchGetCodeSnippetResponse
Retrieves code snippets from findings that Amazon Inspector detected code vulnerabilities in.
-
#batch_get_finding_details(params = {}) ⇒ Types::BatchGetFindingDetailsResponse
Gets vulnerability details for findings.
-
#batch_get_free_trial_info(params = {}) ⇒ Types::BatchGetFreeTrialInfoResponse
Gets free trial status for multiple Amazon Web Services accounts.
-
#batch_get_member_ec2_deep_inspection_status(params = {}) ⇒ Types::BatchGetMemberEc2DeepInspectionStatusResponse
Retrieves Amazon Inspector deep inspection activation status of multiple member accounts within your organization.
-
#batch_update_member_ec2_deep_inspection_status(params = {}) ⇒ Types::BatchUpdateMemberEc2DeepInspectionStatusResponse
Activates or deactivates Amazon Inspector deep inspection for the provided member accounts in your organization.
-
#cancel_findings_report(params = {}) ⇒ Types::CancelFindingsReportResponse
Cancels the given findings report.
-
#cancel_sbom_export(params = {}) ⇒ Types::CancelSbomExportResponse
Cancels a software bill of materials (SBOM) report.
-
#create_cis_scan_configuration(params = {}) ⇒ Types::CreateCisScanConfigurationResponse
Creates a CIS scan configuration.
-
#create_code_security_integration(params = {}) ⇒ Types::CreateCodeSecurityIntegrationResponse
Creates a code security integration with a source code repository provider.
-
#create_code_security_scan_configuration(params = {}) ⇒ Types::CreateCodeSecurityScanConfigurationResponse
Creates a scan configuration for code security scanning.
-
#create_filter(params = {}) ⇒ Types::CreateFilterResponse
Creates a filter resource using specified filter criteria.
-
#create_findings_report(params = {}) ⇒ Types::CreateFindingsReportResponse
Creates a finding report.
-
#create_sbom_export(params = {}) ⇒ Types::CreateSbomExportResponse
Creates a software bill of materials (SBOM) report.
-
#delete_cis_scan_configuration(params = {}) ⇒ Types::DeleteCisScanConfigurationResponse
Deletes a CIS scan configuration.
-
#delete_code_security_integration(params = {}) ⇒ Types::DeleteCodeSecurityIntegrationResponse
Deletes a code security integration.
-
#delete_code_security_scan_configuration(params = {}) ⇒ Types::DeleteCodeSecurityScanConfigurationResponse
Deletes a code security scan configuration.
-
#delete_filter(params = {}) ⇒ Types::DeleteFilterResponse
Deletes a filter resource.
-
#describe_organization_configuration(params = {}) ⇒ Types::DescribeOrganizationConfigurationResponse
Describe Amazon Inspector configuration settings for an Amazon Web Services organization.
-
#disable(params = {}) ⇒ Types::DisableResponse
Disables Amazon Inspector scans for one or more Amazon Web Services accounts.
-
#disable_delegated_admin_account(params = {}) ⇒ Types::DisableDelegatedAdminAccountResponse
Disables the Amazon Inspector delegated administrator for your organization.
-
#disassociate_member(params = {}) ⇒ Types::DisassociateMemberResponse
Disassociates a member account from an Amazon Inspector delegated administrator.
-
#enable(params = {}) ⇒ Types::EnableResponse
Enables Amazon Inspector scans for one or more Amazon Web Services accounts.
-
#enable_delegated_admin_account(params = {}) ⇒ Types::EnableDelegatedAdminAccountResponse
Enables the Amazon Inspector delegated administrator for your Organizations organization.
-
#get_cis_scan_report(params = {}) ⇒ Types::GetCisScanReportResponse
Retrieves a CIS scan report.
-
#get_cis_scan_result_details(params = {}) ⇒ Types::GetCisScanResultDetailsResponse
Retrieves CIS scan result details.
-
#get_clusters_for_image(params = {}) ⇒ Types::GetClustersForImageResponse
Returns a list of clusters and metadata associated with an image.
-
#get_code_security_integration(params = {}) ⇒ Types::GetCodeSecurityIntegrationResponse
Retrieves information about a code security integration.
-
#get_code_security_scan(params = {}) ⇒ Types::GetCodeSecurityScanResponse
Retrieves information about a specific code security scan.
-
#get_code_security_scan_configuration(params = {}) ⇒ Types::GetCodeSecurityScanConfigurationResponse
Retrieves information about a code security scan configuration.
-
#get_configuration(params = {}) ⇒ Types::GetConfigurationResponse
Retrieves setting configurations for Inspector scans.
-
#get_delegated_admin_account(params = {}) ⇒ Types::GetDelegatedAdminAccountResponse
Retrieves information about the Amazon Inspector delegated administrator for your organization.
-
#get_ec2_deep_inspection_configuration(params = {}) ⇒ Types::GetEc2DeepInspectionConfigurationResponse
Retrieves the activation status of Amazon Inspector deep inspection and custom paths associated with your account.
-
#get_encryption_key(params = {}) ⇒ Types::GetEncryptionKeyResponse
Gets an encryption key.
-
#get_findings_report_status(params = {}) ⇒ Types::GetFindingsReportStatusResponse
Gets the status of a findings report.
-
#get_member(params = {}) ⇒ Types::GetMemberResponse
Gets member information for your organization.
-
#get_sbom_export(params = {}) ⇒ Types::GetSbomExportResponse
Gets details of a software bill of materials (SBOM) report.
-
#list_account_permissions(params = {}) ⇒ Types::ListAccountPermissionsResponse
Lists the permissions an account has to configure Amazon Inspector.
-
#list_cis_scan_configurations(params = {}) ⇒ Types::ListCisScanConfigurationsResponse
Lists CIS scan configurations.
-
#list_cis_scan_results_aggregated_by_checks(params = {}) ⇒ Types::ListCisScanResultsAggregatedByChecksResponse
Lists scan results aggregated by checks.
-
#list_cis_scan_results_aggregated_by_target_resource(params = {}) ⇒ Types::ListCisScanResultsAggregatedByTargetResourceResponse
Lists scan results aggregated by a target resource.
-
#list_cis_scans(params = {}) ⇒ Types::ListCisScansResponse
Returns a CIS scan list.
-
#list_code_security_integrations(params = {}) ⇒ Types::ListCodeSecurityIntegrationsResponse
Lists all code security integrations in your account.
-
#list_code_security_scan_configuration_associations(params = {}) ⇒ Types::ListCodeSecurityScanConfigurationAssociationsResponse
Lists the associations between code repositories and Amazon Inspector code security scan configurations.
-
#list_code_security_scan_configurations(params = {}) ⇒ Types::ListCodeSecurityScanConfigurationsResponse
Lists all code security scan configurations in your account.
-
#list_coverage(params = {}) ⇒ Types::ListCoverageResponse
Lists coverage details for your environment.
-
#list_coverage_statistics(params = {}) ⇒ Types::ListCoverageStatisticsResponse
Lists Amazon Inspector coverage statistics for your environment.
-
#list_delegated_admin_accounts(params = {}) ⇒ Types::ListDelegatedAdminAccountsResponse
Lists information about the Amazon Inspector delegated administrator of your organization.
-
#list_filters(params = {}) ⇒ Types::ListFiltersResponse
Lists the filters associated with your account.
-
#list_finding_aggregations(params = {}) ⇒ Types::ListFindingAggregationsResponse
Lists aggregated finding data for your environment based on specific criteria.
-
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Lists findings for your environment.
-
#list_members(params = {}) ⇒ Types::ListMembersResponse
List members associated with the Amazon Inspector delegated administrator for your organization.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags attached to a given resource.
-
#list_usage_totals(params = {}) ⇒ Types::ListUsageTotalsResponse
Lists the Amazon Inspector usage totals over the last 30 days.
-
#reset_encryption_key(params = {}) ⇒ Struct
Resets an encryption key.
-
#search_vulnerabilities(params = {}) ⇒ Types::SearchVulnerabilitiesResponse
Lists Amazon Inspector coverage details for a specific vulnerability.
-
#send_cis_session_health(params = {}) ⇒ Struct
Sends a CIS session health.
-
#send_cis_session_telemetry(params = {}) ⇒ Struct
Sends a CIS session telemetry.
-
#start_cis_session(params = {}) ⇒ Struct
Starts a CIS session.
-
#start_code_security_scan(params = {}) ⇒ Types::StartCodeSecurityScanResponse
Initiates a code security scan on a specified repository.
-
#stop_cis_session(params = {}) ⇒ Struct
Stops a CIS session.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_cis_scan_configuration(params = {}) ⇒ Types::UpdateCisScanConfigurationResponse
Updates a CIS scan configuration.
-
#update_code_security_integration(params = {}) ⇒ Types::UpdateCodeSecurityIntegrationResponse
Updates an existing code security integration.
-
#update_code_security_scan_configuration(params = {}) ⇒ Types::UpdateCodeSecurityScanConfigurationResponse
Updates an existing code security scan configuration.
-
#update_configuration(params = {}) ⇒ Struct
Updates setting configurations for your Amazon Inspector account.
-
#update_ec2_deep_inspection_configuration(params = {}) ⇒ Types::UpdateEc2DeepInspectionConfigurationResponse
Activates, deactivates Amazon Inspector deep inspection, or updates custom paths for your account.
-
#update_encryption_key(params = {}) ⇒ Struct
Updates an encryption key.
-
#update_filter(params = {}) ⇒ Types::UpdateFilterResponse
Specifies the action that is to be applied to the findings that match the filter.
-
#update_org_ec2_deep_inspection_configuration(params = {}) ⇒ Struct
Updates the Amazon Inspector deep inspection custom paths for your organization.
-
#update_organization_configuration(params = {}) ⇒ Types::UpdateOrganizationConfigurationResponse
Updates the configurations for your Amazon Inspector organization.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-inspector2/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6820 6821 6822 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6820 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6823 6824 6825 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6823 def errors_module Errors end |
Instance Method Details
#associate_member(params = {}) ⇒ Types::AssociateMemberResponse
Associates an Amazon Web Services account with an Amazon Inspector delegated administrator. An HTTP 200 response indicates the association was successfully started, but doesn’t indicate whether it was completed. You can check if the association completed by using
- ListMembers][1
-
for multiple accounts or [GetMembers] for a single
account.
[1]: docs.aws.amazon.com/inspector/v2/APIReference/API_ListMembers.html [2]: docs.aws.amazon.com/inspector/v2/APIReference/API_GetMember.html
511 512 513 514 |
# File 'lib/aws-sdk-inspector2/client.rb', line 511 def associate_member(params = {}, = {}) req = build_request(:associate_member, params) req.send_request() end |
#batch_associate_code_security_scan_configuration(params = {}) ⇒ Types::BatchAssociateCodeSecurityScanConfigurationResponse
Associates multiple code repositories with an Amazon Inspector code security scan configuration.
556 557 558 559 |
# File 'lib/aws-sdk-inspector2/client.rb', line 556 def batch_associate_code_security_scan_configuration(params = {}, = {}) req = build_request(:batch_associate_code_security_scan_configuration, params) req.send_request() end |
#batch_disassociate_code_security_scan_configuration(params = {}) ⇒ Types::BatchDisassociateCodeSecurityScanConfigurationResponse
Disassociates multiple code repositories from an Amazon Inspector code security scan configuration.
601 602 603 604 |
# File 'lib/aws-sdk-inspector2/client.rb', line 601 def batch_disassociate_code_security_scan_configuration(params = {}, = {}) req = build_request(:batch_disassociate_code_security_scan_configuration, params) req.send_request() end |
#batch_get_account_status(params = {}) ⇒ Types::BatchGetAccountStatusResponse
Retrieves the Amazon Inspector status of multiple Amazon Web Services accounts within your environment.
661 662 663 664 |
# File 'lib/aws-sdk-inspector2/client.rb', line 661 def batch_get_account_status(params = {}, = {}) req = build_request(:batch_get_account_status, params) req.send_request() end |
#batch_get_code_snippet(params = {}) ⇒ Types::BatchGetCodeSnippetResponse
Retrieves code snippets from findings that Amazon Inspector detected code vulnerabilities in.
705 706 707 708 |
# File 'lib/aws-sdk-inspector2/client.rb', line 705 def batch_get_code_snippet(params = {}, = {}) req = build_request(:batch_get_code_snippet, params) req.send_request() end |
#batch_get_finding_details(params = {}) ⇒ Types::BatchGetFindingDetailsResponse
Gets vulnerability details for findings.
815 816 817 818 |
# File 'lib/aws-sdk-inspector2/client.rb', line 815 def batch_get_finding_details(params = {}, = {}) req = build_request(:batch_get_finding_details, params) req.send_request() end |
#batch_get_free_trial_info(params = {}) ⇒ Types::BatchGetFreeTrialInfoResponse
Gets free trial status for multiple Amazon Web Services accounts.
854 855 856 857 |
# File 'lib/aws-sdk-inspector2/client.rb', line 854 def batch_get_free_trial_info(params = {}, = {}) req = build_request(:batch_get_free_trial_info, params) req.send_request() end |
#batch_get_member_ec2_deep_inspection_status(params = {}) ⇒ Types::BatchGetMemberEc2DeepInspectionStatusResponse
Retrieves Amazon Inspector deep inspection activation status of multiple member accounts within your organization. You must be the delegated administrator of an organization in Amazon Inspector to use this API.
894 895 896 897 |
# File 'lib/aws-sdk-inspector2/client.rb', line 894 def batch_get_member_ec2_deep_inspection_status(params = {}, = {}) req = build_request(:batch_get_member_ec2_deep_inspection_status, params) req.send_request() end |
#batch_update_member_ec2_deep_inspection_status(params = {}) ⇒ Types::BatchUpdateMemberEc2DeepInspectionStatusResponse
Activates or deactivates Amazon Inspector deep inspection for the provided member accounts in your organization. You must be the delegated administrator of an organization in Amazon Inspector to use this API.
939 940 941 942 |
# File 'lib/aws-sdk-inspector2/client.rb', line 939 def batch_update_member_ec2_deep_inspection_status(params = {}, = {}) req = build_request(:batch_update_member_ec2_deep_inspection_status, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6793 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Inspector2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-inspector2' context[:gem_version] = '1.73.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_findings_report(params = {}) ⇒ Types::CancelFindingsReportResponse
Cancels the given findings report.
967 968 969 970 |
# File 'lib/aws-sdk-inspector2/client.rb', line 967 def cancel_findings_report(params = {}, = {}) req = build_request(:cancel_findings_report, params) req.send_request() end |
#cancel_sbom_export(params = {}) ⇒ Types::CancelSbomExportResponse
Cancels a software bill of materials (SBOM) report.
995 996 997 998 |
# File 'lib/aws-sdk-inspector2/client.rb', line 995 def cancel_sbom_export(params = {}, = {}) req = build_request(:cancel_sbom_export, params) req.send_request() end |
#create_cis_scan_configuration(params = {}) ⇒ Types::CreateCisScanConfigurationResponse
Creates a CIS scan configuration.
1101 1102 1103 1104 |
# File 'lib/aws-sdk-inspector2/client.rb', line 1101 def create_cis_scan_configuration(params = {}, = {}) req = build_request(:create_cis_scan_configuration, params) req.send_request() end |
#create_code_security_integration(params = {}) ⇒ Types::CreateCodeSecurityIntegrationResponse
Creates a code security integration with a source code repository provider.
After calling the ‘CreateCodeSecurityIntegration` operation, you complete authentication and authorization with your provider. Next you call the `UpdateCodeSecurityIntegration` operation to provide the `details` to complete the integration setup
1158 1159 1160 1161 |
# File 'lib/aws-sdk-inspector2/client.rb', line 1158 def create_code_security_integration(params = {}, = {}) req = build_request(:create_code_security_integration, params) req.send_request() end |
#create_code_security_scan_configuration(params = {}) ⇒ Types::CreateCodeSecurityScanConfigurationResponse
Creates a scan configuration for code security scanning.
1222 1223 1224 1225 |
# File 'lib/aws-sdk-inspector2/client.rb', line 1222 def create_code_security_scan_configuration(params = {}, = {}) req = build_request(:create_code_security_scan_configuration, params) req.send_request() end |
#create_filter(params = {}) ⇒ Types::CreateFilterResponse
Creates a filter resource using specified filter criteria. When the filter action is set to ‘SUPPRESS` this action creates a suppression rule.
1585 1586 1587 1588 |
# File 'lib/aws-sdk-inspector2/client.rb', line 1585 def create_filter(params = {}, = {}) req = build_request(:create_filter, params) req.send_request() end |
#create_findings_report(params = {}) ⇒ Types::CreateFindingsReportResponse
Creates a finding report. By default only ‘ACTIVE` findings are returned in the report. To see `SUPRESSED` or `CLOSED` findings you must specify a value for the `findingStatus` filter criteria.
1935 1936 1937 1938 |
# File 'lib/aws-sdk-inspector2/client.rb', line 1935 def create_findings_report(params = {}, = {}) req = build_request(:create_findings_report, params) req.send_request() end |
#create_sbom_export(params = {}) ⇒ Types::CreateSbomExportResponse
Creates a software bill of materials (SBOM) report.
2028 2029 2030 2031 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2028 def create_sbom_export(params = {}, = {}) req = build_request(:create_sbom_export, params) req.send_request() end |
#delete_cis_scan_configuration(params = {}) ⇒ Types::DeleteCisScanConfigurationResponse
Deletes a CIS scan configuration.
2068 2069 2070 2071 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2068 def delete_cis_scan_configuration(params = {}, = {}) req = build_request(:delete_cis_scan_configuration, params) req.send_request() end |
#delete_code_security_integration(params = {}) ⇒ Types::DeleteCodeSecurityIntegrationResponse
Deletes a code security integration.
2097 2098 2099 2100 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2097 def delete_code_security_integration(params = {}, = {}) req = build_request(:delete_code_security_integration, params) req.send_request() end |
#delete_code_security_scan_configuration(params = {}) ⇒ Types::DeleteCodeSecurityScanConfigurationResponse
Deletes a code security scan configuration.
2125 2126 2127 2128 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2125 def delete_code_security_scan_configuration(params = {}, = {}) req = build_request(:delete_code_security_scan_configuration, params) req.send_request() end |
#delete_filter(params = {}) ⇒ Types::DeleteFilterResponse
Deletes a filter resource.
2153 2154 2155 2156 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2153 def delete_filter(params = {}, = {}) req = build_request(:delete_filter, params) req.send_request() end |
#describe_organization_configuration(params = {}) ⇒ Types::DescribeOrganizationConfigurationResponse
Describe Amazon Inspector configuration settings for an Amazon Web Services organization.
2179 2180 2181 2182 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2179 def describe_organization_configuration(params = {}, = {}) req = build_request(:describe_organization_configuration, params) req.send_request() end |
#disable(params = {}) ⇒ Types::DisableResponse
Disables Amazon Inspector scans for one or more Amazon Web Services accounts. Disabling all scan types in an account disables the Amazon Inspector service.
2232 2233 2234 2235 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2232 def disable(params = {}, = {}) req = build_request(:disable, params) req.send_request() end |
#disable_delegated_admin_account(params = {}) ⇒ Types::DisableDelegatedAdminAccountResponse
Disables the Amazon Inspector delegated administrator for your organization.
2262 2263 2264 2265 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2262 def disable_delegated_admin_account(params = {}, = {}) req = build_request(:disable_delegated_admin_account, params) req.send_request() end |
#disassociate_member(params = {}) ⇒ Types::DisassociateMemberResponse
Disassociates a member account from an Amazon Inspector delegated administrator.
2292 2293 2294 2295 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2292 def disassociate_member(params = {}, = {}) req = build_request(:disassociate_member, params) req.send_request() end |
#enable(params = {}) ⇒ Types::EnableResponse
Enables Amazon Inspector scans for one or more Amazon Web Services accounts.
2350 2351 2352 2353 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2350 def enable(params = {}, = {}) req = build_request(:enable, params) req.send_request() end |
#enable_delegated_admin_account(params = {}) ⇒ Types::EnableDelegatedAdminAccountResponse
Enables the Amazon Inspector delegated administrator for your Organizations organization.
2387 2388 2389 2390 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2387 def enable_delegated_admin_account(params = {}, = {}) req = build_request(:enable_delegated_admin_account, params) req.send_request() end |
#get_cis_scan_report(params = {}) ⇒ Types::GetCisScanReportResponse
Retrieves a CIS scan report.
2440 2441 2442 2443 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2440 def get_cis_scan_report(params = {}, = {}) req = build_request(:get_cis_scan_report, params) req.send_request() end |
#get_cis_scan_result_details(params = {}) ⇒ Types::GetCisScanResultDetailsResponse
Retrieves CIS scan result details.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2572 2573 2574 2575 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2572 def get_cis_scan_result_details(params = {}, = {}) req = build_request(:get_cis_scan_result_details, params) req.send_request() end |
#get_clusters_for_image(params = {}) ⇒ Types::GetClustersForImageResponse
Returns a list of clusters and metadata associated with an image.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2627 2628 2629 2630 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2627 def get_clusters_for_image(params = {}, = {}) req = build_request(:get_clusters_for_image, params) req.send_request() end |
#get_code_security_integration(params = {}) ⇒ Types::GetCodeSecurityIntegrationResponse
Retrieves information about a code security integration.
2679 2680 2681 2682 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2679 def get_code_security_integration(params = {}, = {}) req = build_request(:get_code_security_integration, params) req.send_request() end |
#get_code_security_scan(params = {}) ⇒ Types::GetCodeSecurityScanResponse
Retrieves information about a specific code security scan.
2727 2728 2729 2730 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2727 def get_code_security_scan(params = {}, = {}) req = build_request(:get_code_security_scan, params) req.send_request() end |
#get_code_security_scan_configuration(params = {}) ⇒ Types::GetCodeSecurityScanConfigurationResponse
Retrieves information about a code security scan configuration.
2775 2776 2777 2778 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2775 def get_code_security_scan_configuration(params = {}, = {}) req = build_request(:get_code_security_scan_configuration, params) req.send_request() end |
#get_configuration(params = {}) ⇒ Types::GetConfigurationResponse
Retrieves setting configurations for Inspector scans.
2801 2802 2803 2804 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2801 def get_configuration(params = {}, = {}) req = build_request(:get_configuration, params) req.send_request() end |
#get_delegated_admin_account(params = {}) ⇒ Types::GetDelegatedAdminAccountResponse
Retrieves information about the Amazon Inspector delegated administrator for your organization.
2822 2823 2824 2825 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2822 def get_delegated_admin_account(params = {}, = {}) req = build_request(:get_delegated_admin_account, params) req.send_request() end |
#get_ec2_deep_inspection_configuration(params = {}) ⇒ Types::GetEc2DeepInspectionConfigurationResponse
Retrieves the activation status of Amazon Inspector deep inspection and custom paths associated with your account.
2850 2851 2852 2853 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2850 def get_ec2_deep_inspection_configuration(params = {}, = {}) req = build_request(:get_ec2_deep_inspection_configuration, params) req.send_request() end |
#get_encryption_key(params = {}) ⇒ Types::GetEncryptionKeyResponse
Gets an encryption key.
2882 2883 2884 2885 |
# File 'lib/aws-sdk-inspector2/client.rb', line 2882 def get_encryption_key(params = {}, = {}) req = build_request(:get_encryption_key, params) req.send_request() end |
#get_findings_report_status(params = {}) ⇒ Types::GetFindingsReportStatusResponse
Gets the status of a findings report.
3074 3075 3076 3077 |
# File 'lib/aws-sdk-inspector2/client.rb', line 3074 def get_findings_report_status(params = {}, = {}) req = build_request(:get_findings_report_status, params) req.send_request() end |
#get_member(params = {}) ⇒ Types::GetMemberResponse
Gets member information for your organization.
3106 3107 3108 3109 |
# File 'lib/aws-sdk-inspector2/client.rb', line 3106 def get_member(params = {}, = {}) req = build_request(:get_member, params) req.send_request() end |
#get_sbom_export(params = {}) ⇒ Types::GetSbomExportResponse
Gets details of a software bill of materials (SBOM) report.
3173 3174 3175 3176 |
# File 'lib/aws-sdk-inspector2/client.rb', line 3173 def get_sbom_export(params = {}, = {}) req = build_request(:get_sbom_export, params) req.send_request() end |
#list_account_permissions(params = {}) ⇒ Types::ListAccountPermissionsResponse
Lists the permissions an account has to configure Amazon Inspector. If the account is a member account or standalone account with resources managed by an Organizations policy, the operation returns fewer permissions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3226 3227 3228 3229 |
# File 'lib/aws-sdk-inspector2/client.rb', line 3226 def (params = {}, = {}) req = build_request(:list_account_permissions, params) req.send_request() end |
#list_cis_scan_configurations(params = {}) ⇒ Types::ListCisScanConfigurationsResponse
Lists CIS scan configurations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3352 3353 3354 3355 |
# File 'lib/aws-sdk-inspector2/client.rb', line 3352 def list_cis_scan_configurations(params = {}, = {}) req = build_request(:list_cis_scan_configurations, params) req.send_request() end |
#list_cis_scan_results_aggregated_by_checks(params = {}) ⇒ Types::ListCisScanResultsAggregatedByChecksResponse
Lists scan results aggregated by checks.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3480 3481 3482 3483 |
# File 'lib/aws-sdk-inspector2/client.rb', line 3480 def list_cis_scan_results_aggregated_by_checks(params = {}, = {}) req = build_request(:list_cis_scan_results_aggregated_by_checks, params) req.send_request() end |
#list_cis_scan_results_aggregated_by_target_resource(params = {}) ⇒ Types::ListCisScanResultsAggregatedByTargetResourceResponse
Lists scan results aggregated by a target resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3632 3633 3634 3635 |
# File 'lib/aws-sdk-inspector2/client.rb', line 3632 def list_cis_scan_results_aggregated_by_target_resource(params = {}, = {}) req = build_request(:list_cis_scan_results_aggregated_by_target_resource, params) req.send_request() end |
#list_cis_scans(params = {}) ⇒ Types::ListCisScansResponse
Returns a CIS scan list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3794 3795 3796 3797 |
# File 'lib/aws-sdk-inspector2/client.rb', line 3794 def list_cis_scans(params = {}, = {}) req = build_request(:list_cis_scans, params) req.send_request() end |
#list_code_security_integrations(params = {}) ⇒ Types::ListCodeSecurityIntegrationsResponse
Lists all code security integrations in your account.
3840 3841 3842 3843 |
# File 'lib/aws-sdk-inspector2/client.rb', line 3840 def list_code_security_integrations(params = {}, = {}) req = build_request(:list_code_security_integrations, params) req.send_request() end |
#list_code_security_scan_configuration_associations(params = {}) ⇒ Types::ListCodeSecurityScanConfigurationAssociationsResponse
Lists the associations between code repositories and Amazon Inspector code security scan configurations.
3888 3889 3890 3891 |
# File 'lib/aws-sdk-inspector2/client.rb', line 3888 def list_code_security_scan_configuration_associations(params = {}, = {}) req = build_request(:list_code_security_scan_configuration_associations, params) req.send_request() end |
#list_code_security_scan_configurations(params = {}) ⇒ Types::ListCodeSecurityScanConfigurationsResponse
Lists all code security scan configurations in your account.
3937 3938 3939 3940 |
# File 'lib/aws-sdk-inspector2/client.rb', line 3937 def list_code_security_scan_configurations(params = {}, = {}) req = build_request(:list_code_security_scan_configurations, params) req.send_request() end |
#list_coverage(params = {}) ⇒ Types::ListCoverageResponse
Lists coverage details for your environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4157 4158 4159 4160 |
# File 'lib/aws-sdk-inspector2/client.rb', line 4157 def list_coverage(params = {}, = {}) req = build_request(:list_coverage, params) req.send_request() end |
#list_coverage_statistics(params = {}) ⇒ Types::ListCoverageStatisticsResponse
Lists Amazon Inspector coverage statistics for your environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4335 4336 4337 4338 |
# File 'lib/aws-sdk-inspector2/client.rb', line 4335 def list_coverage_statistics(params = {}, = {}) req = build_request(:list_coverage_statistics, params) req.send_request() end |
#list_delegated_admin_accounts(params = {}) ⇒ Types::ListDelegatedAdminAccountsResponse
Lists information about the Amazon Inspector delegated administrator of your organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4382 4383 4384 4385 |
# File 'lib/aws-sdk-inspector2/client.rb', line 4382 def list_delegated_admin_accounts(params = {}, = {}) req = build_request(:list_delegated_admin_accounts, params) req.send_request() end |
#list_filters(params = {}) ⇒ Types::ListFiltersResponse
Lists the filters associated with your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4597 4598 4599 4600 |
# File 'lib/aws-sdk-inspector2/client.rb', line 4597 def list_filters(params = {}, = {}) req = build_request(:list_filters, params) req.send_request() end |
#list_finding_aggregations(params = {}) ⇒ Types::ListFindingAggregationsResponse
Lists aggregated finding data for your environment based on specific criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4996 4997 4998 4999 |
# File 'lib/aws-sdk-inspector2/client.rb', line 4996 def list_finding_aggregations(params = {}, = {}) req = build_request(:list_finding_aggregations, params) req.send_request() end |
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Lists findings for your environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5481 5482 5483 5484 |
# File 'lib/aws-sdk-inspector2/client.rb', line 5481 def list_findings(params = {}, = {}) req = build_request(:list_findings, params) req.send_request() end |
#list_members(params = {}) ⇒ Types::ListMembersResponse
List members associated with the Amazon Inspector delegated administrator for your organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5535 5536 5537 5538 |
# File 'lib/aws-sdk-inspector2/client.rb', line 5535 def list_members(params = {}, = {}) req = build_request(:list_members, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags attached to a given resource.
5564 5565 5566 5567 |
# File 'lib/aws-sdk-inspector2/client.rb', line 5564 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_usage_totals(params = {}) ⇒ Types::ListUsageTotalsResponse
Lists the Amazon Inspector usage totals over the last 30 days.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5618 5619 5620 5621 |
# File 'lib/aws-sdk-inspector2/client.rb', line 5618 def list_usage_totals(params = {}, = {}) req = build_request(:list_usage_totals, params) req.send_request() end |
#reset_encryption_key(params = {}) ⇒ Struct
Resets an encryption key. After the key is reset your resources will be encrypted by an Amazon Web Services owned key.
5645 5646 5647 5648 |
# File 'lib/aws-sdk-inspector2/client.rb', line 5645 def reset_encryption_key(params = {}, = {}) req = build_request(:reset_encryption_key, params) req.send_request() end |
#search_vulnerabilities(params = {}) ⇒ Types::SearchVulnerabilitiesResponse
Lists Amazon Inspector coverage details for a specific vulnerability.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5720 5721 5722 5723 |
# File 'lib/aws-sdk-inspector2/client.rb', line 5720 def search_vulnerabilities(params = {}, = {}) req = build_request(:search_vulnerabilities, params) req.send_request() end |
#send_cis_session_health(params = {}) ⇒ Struct
Sends a CIS session health. This API is used by the Amazon Inspector SSM plugin to communicate with the Amazon Inspector service. The Amazon Inspector SSM plugin calls this API to start a CIS scan session for the scan ID supplied by the service.
5761 5762 5763 5764 |
# File 'lib/aws-sdk-inspector2/client.rb', line 5761 def send_cis_session_health(params = {}, = {}) req = build_request(:send_cis_session_health, params) req.send_request() end |
#send_cis_session_telemetry(params = {}) ⇒ Struct
Sends a CIS session telemetry. This API is used by the Amazon Inspector SSM plugin to communicate with the Amazon Inspector service. The Amazon Inspector SSM plugin calls this API to start a CIS scan session for the scan ID supplied by the service.
5824 5825 5826 5827 |
# File 'lib/aws-sdk-inspector2/client.rb', line 5824 def send_cis_session_telemetry(params = {}, = {}) req = build_request(:send_cis_session_telemetry, params) req.send_request() end |
#start_cis_session(params = {}) ⇒ Struct
Starts a CIS session. This API is used by the Amazon Inspector SSM plugin to communicate with the Amazon Inspector service. The Amazon Inspector SSM plugin calls this API to start a CIS scan session for the scan ID supplied by the service.
5869 5870 5871 5872 |
# File 'lib/aws-sdk-inspector2/client.rb', line 5869 def start_cis_session(params = {}, = {}) req = build_request(:start_cis_session, params) req.send_request() end |
#start_code_security_scan(params = {}) ⇒ Types::StartCodeSecurityScanResponse
Initiates a code security scan on a specified repository.
5909 5910 5911 5912 |
# File 'lib/aws-sdk-inspector2/client.rb', line 5909 def start_code_security_scan(params = {}, = {}) req = build_request(:start_code_security_scan, params) req.send_request() end |
#stop_cis_session(params = {}) ⇒ Struct
Stops a CIS session. This API is used by the Amazon Inspector SSM plugin to communicate with the Amazon Inspector service. The Amazon Inspector SSM plugin calls this API to stop a CIS scan session for the scan ID supplied by the service.
5995 5996 5997 5998 |
# File 'lib/aws-sdk-inspector2/client.rb', line 5995 def stop_cis_session(params = {}, = {}) req = build_request(:stop_cis_session, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
6023 6024 6025 6026 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6023 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
6049 6050 6051 6052 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6049 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_cis_scan_configuration(params = {}) ⇒ Types::UpdateCisScanConfigurationResponse
Updates a CIS scan configuration.
6154 6155 6156 6157 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6154 def update_cis_scan_configuration(params = {}, = {}) req = build_request(:update_cis_scan_configuration, params) req.send_request() end |
#update_code_security_integration(params = {}) ⇒ Types::UpdateCodeSecurityIntegrationResponse
Updates an existing code security integration.
After calling the ‘CreateCodeSecurityIntegration` operation, you complete authentication and authorization with your provider. Next you call the `UpdateCodeSecurityIntegration` operation to provide the `details` to complete the integration setup
6203 6204 6205 6206 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6203 def update_code_security_integration(params = {}, = {}) req = build_request(:update_code_security_integration, params) req.send_request() end |
#update_code_security_scan_configuration(params = {}) ⇒ Types::UpdateCodeSecurityScanConfigurationResponse
Updates an existing code security scan configuration.
6244 6245 6246 6247 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6244 def update_code_security_scan_configuration(params = {}, = {}) req = build_request(:update_code_security_scan_configuration, params) req.send_request() end |
#update_configuration(params = {}) ⇒ Struct
Updates setting configurations for your Amazon Inspector account. When you use this API as an Amazon Inspector delegated administrator this updates the setting for all accounts you manage. Member accounts in an organization cannot update this setting.
6281 6282 6283 6284 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6281 def update_configuration(params = {}, = {}) req = build_request(:update_configuration, params) req.send_request() end |
#update_ec2_deep_inspection_configuration(params = {}) ⇒ Types::UpdateEc2DeepInspectionConfigurationResponse
Activates, deactivates Amazon Inspector deep inspection, or updates custom paths for your account.
6331 6332 6333 6334 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6331 def update_ec2_deep_inspection_configuration(params = {}, = {}) req = build_request(:update_ec2_deep_inspection_configuration, params) req.send_request() end |
#update_encryption_key(params = {}) ⇒ Struct
Updates an encryption key. A ‘ResourceNotFoundException` means that an Amazon Web Services owned key is being used for encryption.
6362 6363 6364 6365 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6362 def update_encryption_key(params = {}, = {}) req = build_request(:update_encryption_key, params) req.send_request() end |
#update_filter(params = {}) ⇒ Types::UpdateFilterResponse
Specifies the action that is to be applied to the findings that match the filter.
6720 6721 6722 6723 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6720 def update_filter(params = {}, = {}) req = build_request(:update_filter, params) req.send_request() end |
#update_org_ec2_deep_inspection_configuration(params = {}) ⇒ Struct
Updates the Amazon Inspector deep inspection custom paths for your organization. You must be an Amazon Inspector delegated administrator to use this API.
6745 6746 6747 6748 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6745 def update_org_ec2_deep_inspection_configuration(params = {}, = {}) req = build_request(:update_org_ec2_deep_inspection_configuration, params) req.send_request() end |
#update_organization_configuration(params = {}) ⇒ Types::UpdateOrganizationConfigurationResponse
Updates the configurations for your Amazon Inspector organization.
6784 6785 6786 6787 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6784 def update_organization_configuration(params = {}, = {}) req = build_request(:update_organization_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6813 6814 6815 |
# File 'lib/aws-sdk-inspector2/client.rb', line 6813 def waiter_names [] end |