Class: Aws::Inspector2::Types::AggregationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Note:

AggregationResponse is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AggregationResponse corresponding to the set member.

A structure that contains details about the results of an aggregation type.

Defined Under Namespace

Classes: AccountAggregation, AmiAggregation, AwsEcrContainerAggregation, CodeRepositoryAggregation, ContainerImageAggregation, Ec2InstanceAggregation, FindingTypeAggregation, ImageLayerAggregation, LambdaFunctionAggregation, LambdaLayerAggregation, PackageAggregation, RepositoryAggregation, ServerlessFunctionAggregation, TitleAggregation, Unknown, VmInstanceAggregation

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_aggregation ⇒ Types::AccountAggregationResponse

An object that contains details about an aggregation response based on Amazon Web Services account IDs.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#ami_aggregation ⇒ Types::AmiAggregationResponse

An object that contains details about an aggregation response based on Amazon Machine Images (AMIs).



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#aws_ecr_container_aggregation ⇒ Types::AwsEcrContainerAggregationResponse

An object that contains details about an aggregation response based on Amazon ECR container images.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#code_repository_aggregation ⇒ Types::CodeRepositoryAggregationResponse

An object that contains details about an aggregation response based on code repositories.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#container_image_aggregation ⇒ Types::ContainerImageAggregationResponse

An object that contains details about an aggregation response based on container images.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#ec2_instance_aggregation ⇒ Types::Ec2InstanceAggregationResponse

An object that contains details about an aggregation response based on Amazon EC2 instances.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#finding_type_aggregation ⇒ Types::FindingTypeAggregationResponse

An object that contains details about an aggregation response based on finding types.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#image_layer_aggregation ⇒ Types::ImageLayerAggregationResponse

An object that contains details about an aggregation response based on container image layers.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#lambda_function_aggregation ⇒ Types::LambdaFunctionAggregationResponse

An aggregation of findings by Amazon Web Services Lambda function.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#lambda_layer_aggregation ⇒ Types::LambdaLayerAggregationResponse

An aggregation of findings by Amazon Web Services Lambda layer.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#package_aggregation ⇒ Types::PackageAggregationResponse

An object that contains details about an aggregation response based on operating system package type.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#repository_aggregation ⇒ Types::RepositoryAggregationResponse

An object that contains details about an aggregation response based on Amazon ECR repositories.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#serverless_function_aggregation ⇒ Types::ServerlessFunctionAggregationResponse

An object that contains details about an aggregation response based on serverless functions.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#title_aggregation ⇒ Types::TitleAggregationResponse

An object that contains details about an aggregation response based on finding title.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end

#unknown ⇒ Object

Returns the value of attribute unknown

Returns:

  • (Object) —

    the current value of unknown



339
340
341
# File 'lib/aws-sdk-inspector2/types.rb', line 339

def unknown
  @unknown
end

#vm_instance_aggregation ⇒ Types::VmInstanceAggregationResponse

An object that contains details about an aggregation response based on VM instances.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/aws-sdk-inspector2/types.rb', line 339

class AggregationResponse < Struct.new(
  :account_aggregation,
  :ami_aggregation,
  :aws_ecr_container_aggregation,
  :ec2_instance_aggregation,
  :finding_type_aggregation,
  :image_layer_aggregation,
  :package_aggregation,
  :repository_aggregation,
  :title_aggregation,
  :lambda_layer_aggregation,
  :lambda_function_aggregation,
  :code_repository_aggregation,
  :vm_instance_aggregation,
  :container_image_aggregation,
  :serverless_function_aggregation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AccountAggregation < AggregationResponse; end
  class AmiAggregation < AggregationResponse; end
  class AwsEcrContainerAggregation < AggregationResponse; end
  class Ec2InstanceAggregation < AggregationResponse; end
  class FindingTypeAggregation < AggregationResponse; end
  class ImageLayerAggregation < AggregationResponse; end
  class PackageAggregation < AggregationResponse; end
  class RepositoryAggregation < AggregationResponse; end
  class TitleAggregation < AggregationResponse; end
  class LambdaLayerAggregation < AggregationResponse; end
  class LambdaFunctionAggregation < AggregationResponse; end
  class CodeRepositoryAggregation < AggregationResponse; end
  class VmInstanceAggregation < AggregationResponse; end
  class ContainerImageAggregation < AggregationResponse; end
  class ServerlessFunctionAggregation < AggregationResponse; end
  class Unknown < AggregationResponse; end
end