Class: Aws::Inspector2::Types::AmiAggregationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

A response that contains the results of a finding aggregation by AMI.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The Amazon Web Services account ID for the AMI.

Returns:

  • (String)


462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/aws-sdk-inspector2/types.rb', line 462

class AmiAggregationResponse < Struct.new(
  :ami,
  :account_id,
  :cloud_provider,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :cloud_account_id,
  :severity_counts,
  :affected_instances)
  SENSITIVE = []
  include Aws::Structure
end

#affected_instances ⇒ Integer

The IDs of Amazon EC2 instances using this AMI.

Returns:

  • (Integer)


462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/aws-sdk-inspector2/types.rb', line 462

class AmiAggregationResponse < Struct.new(
  :ami,
  :account_id,
  :cloud_provider,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :cloud_account_id,
  :severity_counts,
  :affected_instances)
  SENSITIVE = []
  include Aws::Structure
end

#ami ⇒ String

The ID of the AMI that findings were aggregated for.

Returns:

  • (String)


462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/aws-sdk-inspector2/types.rb', line 462

class AmiAggregationResponse < Struct.new(
  :ami,
  :account_id,
  :cloud_provider,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :cloud_account_id,
  :severity_counts,
  :affected_instances)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_account_id ⇒ String

The cloud account ID for the AMI aggregation.

Returns:

  • (String)


462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/aws-sdk-inspector2/types.rb', line 462

class AmiAggregationResponse < Struct.new(
  :ami,
  :account_id,
  :cloud_provider,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :cloud_account_id,
  :severity_counts,
  :affected_instances)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_org_id ⇒ String

The cloud organization ID for the AMI aggregation.

Returns:

  • (String)


462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/aws-sdk-inspector2/types.rb', line 462

class AmiAggregationResponse < Struct.new(
  :ami,
  :account_id,
  :cloud_provider,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :cloud_account_id,
  :severity_counts,
  :affected_instances)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_partition ⇒ String

The cloud infrastructure partition associated with this AMI aggregation. Valid values:

  • aws – Amazon Web Services commercial Regions.

  • aws-cn – Amazon Web Services China Regions.

  • aws-us-gov – Amazon Web Services GovCloud (US) Regions.

  • AzureCloud – Azure commercial Regions.

Returns:

  • (String)


462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/aws-sdk-inspector2/types.rb', line 462

class AmiAggregationResponse < Struct.new(
  :ami,
  :account_id,
  :cloud_provider,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :cloud_account_id,
  :severity_counts,
  :affected_instances)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_provider ⇒ String

The cloud service provider associated with this Amazon Machine Image (AMI) aggregation. Valid values:

  • AWS – Findings from Amazon Web Services resources.

  • AZURE – Findings from Microsoft Azure resources.

Returns:

  • (String)


462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/aws-sdk-inspector2/types.rb', line 462

class AmiAggregationResponse < Struct.new(
  :ami,
  :account_id,
  :cloud_provider,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :cloud_account_id,
  :severity_counts,
  :affected_instances)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_region ⇒ String

The cloud Region associated with this AMI aggregation. The value format depends on the cloud provider:

  • An Amazon Web Services Region, such as us-east-1.

  • An Azure region, such as eastus.

Returns:

  • (String)


462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/aws-sdk-inspector2/types.rb', line 462

class AmiAggregationResponse < Struct.new(
  :ami,
  :account_id,
  :cloud_provider,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :cloud_account_id,
  :severity_counts,
  :affected_instances)
  SENSITIVE = []
  include Aws::Structure
end

#severity_counts ⇒ Types::SeverityCounts

An object that contains the count of matched findings per severity.



462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/aws-sdk-inspector2/types.rb', line 462

class AmiAggregationResponse < Struct.new(
  :ami,
  :account_id,
  :cloud_provider,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :cloud_account_id,
  :severity_counts,
  :affected_instances)
  SENSITIVE = []
  include Aws::Structure
end