Class: Aws::Inspector2::Types::AutoEnable

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Represents which scan types are automatically enabled for new members of your Amazon Inspector organization.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_repository ⇒ Boolean

Represents whether code repository scans are automatically enabled for new members of your Amazon Inspector organization.

Returns:

  • (Boolean)


589
590
591
592
593
594
595
596
597
# File 'lib/aws-sdk-inspector2/types.rb', line 589

class AutoEnable < Struct.new(
  :ec2,
  :ecr,
  :lambda,
  :lambda_code,
  :code_repository)
  SENSITIVE = []
  include Aws::Structure
end

#ec2 ⇒ Boolean

Represents whether Amazon EC2 scans are automatically enabled for new members of your Amazon Inspector organization.

Returns:

  • (Boolean)


589
590
591
592
593
594
595
596
597
# File 'lib/aws-sdk-inspector2/types.rb', line 589

class AutoEnable < Struct.new(
  :ec2,
  :ecr,
  :lambda,
  :lambda_code,
  :code_repository)
  SENSITIVE = []
  include Aws::Structure
end

#ecr ⇒ Boolean

Represents whether Amazon ECR scans are automatically enabled for new members of your Amazon Inspector organization.

Returns:

  • (Boolean)


589
590
591
592
593
594
595
596
597
# File 'lib/aws-sdk-inspector2/types.rb', line 589

class AutoEnable < Struct.new(
  :ec2,
  :ecr,
  :lambda,
  :lambda_code,
  :code_repository)
  SENSITIVE = []
  include Aws::Structure
end

#lambda ⇒ Boolean

Represents whether Amazon Web Services Lambda standard scans are automatically enabled for new members of your Amazon Inspector organization.

Returns:

  • (Boolean)


589
590
591
592
593
594
595
596
597
# File 'lib/aws-sdk-inspector2/types.rb', line 589

class AutoEnable < Struct.new(
  :ec2,
  :ecr,
  :lambda,
  :lambda_code,
  :code_repository)
  SENSITIVE = []
  include Aws::Structure
end

#lambda_code ⇒ Boolean

Represents whether Lambda code scans are automatically enabled for new members of your Amazon Inspector organization.

Returns:

  • (Boolean)


589
590
591
592
593
594
595
596
597
# File 'lib/aws-sdk-inspector2/types.rb', line 589

class AutoEnable < Struct.new(
  :ec2,
  :ecr,
  :lambda,
  :lambda_code,
  :code_repository)
  SENSITIVE = []
  include Aws::Structure
end