Class: Aws::Inspector2::Types::AwsLambdaFunctionDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

A summary of information about the Amazon Web Services Lambda function.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#architectures ⇒ Array<String>

The instruction set architecture that the Amazon Web Services Lambda function supports. Architecture is a string array with one of the valid values. The default architecture value is x86_64.

Returns:

  • (Array<String>)


971
972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'lib/aws-sdk-inspector2/types.rb', line 971

class AwsLambdaFunctionDetails < Struct.new(
  :function_name,
  :runtime,
  :code_sha_256,
  :version,
  :execution_role_arn,
  :layers,
  :vpc_config,
  :package_type,
  :architectures,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#code_sha_256 ⇒ String

The SHA256 hash of the Amazon Web Services Lambda function's deployment package.

Returns:

  • (String)


971
972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'lib/aws-sdk-inspector2/types.rb', line 971

class AwsLambdaFunctionDetails < Struct.new(
  :function_name,
  :runtime,
  :code_sha_256,
  :version,
  :execution_role_arn,
  :layers,
  :vpc_config,
  :package_type,
  :architectures,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arn ⇒ String

The Amazon Web Services Lambda function's execution role.

Returns:

  • (String)


971
972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'lib/aws-sdk-inspector2/types.rb', line 971

class AwsLambdaFunctionDetails < Struct.new(
  :function_name,
  :runtime,
  :code_sha_256,
  :version,
  :execution_role_arn,
  :layers,
  :vpc_config,
  :package_type,
  :architectures,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#function_name ⇒ String

The name of the Amazon Web Services Lambda function.

Returns:

  • (String)


971
972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'lib/aws-sdk-inspector2/types.rb', line 971

class AwsLambdaFunctionDetails < Struct.new(
  :function_name,
  :runtime,
  :code_sha_256,
  :version,
  :execution_role_arn,
  :layers,
  :vpc_config,
  :package_type,
  :architectures,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_at ⇒ Time

The date and time that a user last updated the configuration, in ISO 8601 format

Returns:



971
972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'lib/aws-sdk-inspector2/types.rb', line 971

class AwsLambdaFunctionDetails < Struct.new(
  :function_name,
  :runtime,
  :code_sha_256,
  :version,
  :execution_role_arn,
  :layers,
  :vpc_config,
  :package_type,
  :architectures,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#layers ⇒ Array<String>

The Amazon Web Services Lambda function's layers. A Lambda function can have up to five layers.

Returns:

  • (Array<String>)


971
972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'lib/aws-sdk-inspector2/types.rb', line 971

class AwsLambdaFunctionDetails < Struct.new(
  :function_name,
  :runtime,
  :code_sha_256,
  :version,
  :execution_role_arn,
  :layers,
  :vpc_config,
  :package_type,
  :architectures,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#package_type ⇒ String

The type of deployment package. Set to Image for container image and set Zip for .zip file archive.

Returns:

  • (String)


971
972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'lib/aws-sdk-inspector2/types.rb', line 971

class AwsLambdaFunctionDetails < Struct.new(
  :function_name,
  :runtime,
  :code_sha_256,
  :version,
  :execution_role_arn,
  :layers,
  :vpc_config,
  :package_type,
  :architectures,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#runtime ⇒ String

The runtime environment for the Amazon Web Services Lambda function.

Returns:

  • (String)


971
972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'lib/aws-sdk-inspector2/types.rb', line 971

class AwsLambdaFunctionDetails < Struct.new(
  :function_name,
  :runtime,
  :code_sha_256,
  :version,
  :execution_role_arn,
  :layers,
  :vpc_config,
  :package_type,
  :architectures,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ String

The version of the Amazon Web Services Lambda function.

Returns:

  • (String)


971
972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'lib/aws-sdk-inspector2/types.rb', line 971

class AwsLambdaFunctionDetails < Struct.new(
  :function_name,
  :runtime,
  :code_sha_256,
  :version,
  :execution_role_arn,
  :layers,
  :vpc_config,
  :package_type,
  :architectures,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_config ⇒ Types::LambdaVpcConfig

The Amazon Web Services Lambda function's networking configuration.



971
972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'lib/aws-sdk-inspector2/types.rb', line 971

class AwsLambdaFunctionDetails < Struct.new(
  :function_name,
  :runtime,
  :code_sha_256,
  :version,
  :execution_role_arn,
  :layers,
  :vpc_config,
  :package_type,
  :architectures,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end