Class: Aws::Inspector2::Types::AzureScopeConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

The scope of Azure resources to scan, defined separately for VM, container image, and serverless scanning. Provide this when you create or update an Azure connector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_image_scanning ⇒ Types::ScopeConfigurationInput

The scope configuration input for container image scanning.



1090
1091
1092
1093
1094
1095
1096
# File 'lib/aws-sdk-inspector2/types.rb', line 1090

class AzureScopeConfigurationInput < Struct.new(
  :vm_scanning,
  :container_image_scanning,
  :serverless_scanning)
  SENSITIVE = []
  include Aws::Structure
end

#serverless_scanning ⇒ Types::ScopeConfigurationInput

The scope configuration input for serverless scanning.



1090
1091
1092
1093
1094
1095
1096
# File 'lib/aws-sdk-inspector2/types.rb', line 1090

class AzureScopeConfigurationInput < Struct.new(
  :vm_scanning,
  :container_image_scanning,
  :serverless_scanning)
  SENSITIVE = []
  include Aws::Structure
end

#vm_scanning ⇒ Types::ScopeConfigurationInput

The scope configuration input for VM scanning.



1090
1091
1092
1093
1094
1095
1096
# File 'lib/aws-sdk-inspector2/types.rb', line 1090

class AzureScopeConfigurationInput < Struct.new(
  :vm_scanning,
  :container_image_scanning,
  :serverless_scanning)
  SENSITIVE = []
  include Aws::Structure
end