Class: Aws::Inspector2::Types::BatchAssociateCodeSecurityScanConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failed_associations ⇒ Array<Types::FailedAssociationResult>

Details of any code repositories that failed to be associated with the scan configuration.

Returns:



1136
1137
1138
1139
1140
1141
# File 'lib/aws-sdk-inspector2/types.rb', line 1136

class BatchAssociateCodeSecurityScanConfigurationResponse < Struct.new(
  :failed_associations,
  :successful_associations)
  SENSITIVE = []
  include Aws::Structure
end

#successful_associations ⇒ Array<Types::SuccessfulAssociationResult>

Details of code repositories that were successfully associated with the scan configuration.



1136
1137
1138
1139
1140
1141
# File 'lib/aws-sdk-inspector2/types.rb', line 1136

class BatchAssociateCodeSecurityScanConfigurationResponse < Struct.new(
  :failed_associations,
  :successful_associations)
  SENSITIVE = []
  include Aws::Structure
end