Class: Aws::Inspector2::Types::BatchGetCodeSnippetResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_snippet_results ⇒ Array<Types::CodeSnippetResult>

The retrieved code snippets associated with the provided finding ARNs.

Returns:



1232
1233
1234
1235
1236
1237
# File 'lib/aws-sdk-inspector2/types.rb', line 1232

class BatchGetCodeSnippetResponse < Struct.new(
  :code_snippet_results,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end

#errors ⇒ Array<Types::CodeSnippetError>

Any errors Amazon Inspector encountered while trying to retrieve the requested code snippets.

Returns:



1232
1233
1234
1235
1236
1237
# File 'lib/aws-sdk-inspector2/types.rb', line 1232

class BatchGetCodeSnippetResponse < Struct.new(
  :code_snippet_results,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end