Class: Aws::Inspector2::Types::ClusterDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::ClusterDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
Details about the task or pod in the cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_metadata ⇒ Types::ClusterMetadata
The metadata for a cluster.
-
#last_in_use ⇒ Time
The last timestamp when Amazon Inspector recorded the image in use in the task or pod in the cluster.
-
#running_unit_count ⇒ Integer
The number of tasks or pods where an image was running on the cluster.
-
#stopped_unit_count ⇒ Integer
The number of tasks or pods where an image was stopped on the cluster in the last 24 hours.
Instance Attribute Details
#cluster_metadata ⇒ Types::ClusterMetadata
The metadata for a cluster.
2078 2079 2080 2081 2082 2083 2084 2085 |
# File 'lib/aws-sdk-inspector2/types.rb', line 2078 class ClusterDetails < Struct.new( :last_in_use, :running_unit_count, :stopped_unit_count, :cluster_metadata) SENSITIVE = [] include Aws::Structure end |
#last_in_use ⇒ Time
The last timestamp when Amazon Inspector recorded the image in use in the task or pod in the cluster.
2078 2079 2080 2081 2082 2083 2084 2085 |
# File 'lib/aws-sdk-inspector2/types.rb', line 2078 class ClusterDetails < Struct.new( :last_in_use, :running_unit_count, :stopped_unit_count, :cluster_metadata) SENSITIVE = [] include Aws::Structure end |
#running_unit_count ⇒ Integer
The number of tasks or pods where an image was running on the cluster.
2078 2079 2080 2081 2082 2083 2084 2085 |
# File 'lib/aws-sdk-inspector2/types.rb', line 2078 class ClusterDetails < Struct.new( :last_in_use, :running_unit_count, :stopped_unit_count, :cluster_metadata) SENSITIVE = [] include Aws::Structure end |
#stopped_unit_count ⇒ Integer
The number of tasks or pods where an image was stopped on the cluster in the last 24 hours.
2078 2079 2080 2081 2082 2083 2084 2085 |
# File 'lib/aws-sdk-inspector2/types.rb', line 2078 class ClusterDetails < Struct.new( :last_in_use, :running_unit_count, :stopped_unit_count, :cluster_metadata) SENSITIVE = [] include Aws::Structure end |