Class: Aws::Inspector2::Types::CodeSecurityResource

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Note:

CodeSecurityResource is a union - when making an API calls you must set exactly one of the members.

Note:

CodeSecurityResource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CodeSecurityResource corresponding to the set member.

Identifies a specific resource in a code repository that will be scanned.

Defined Under Namespace

Classes: ProjectId, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#project_id ⇒ String

The unique identifier of the project in the code repository.

Returns:

  • (String)


2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
# File 'lib/aws-sdk-inspector2/types.rb', line 2436

class CodeSecurityResource < Struct.new(
  :project_id,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ProjectId < CodeSecurityResource; end
  class Unknown < CodeSecurityResource; end
end

#unknown ⇒ Object

Returns the value of attribute unknown

Returns:

  • (Object) —

    the current value of unknown



2436
2437
2438
# File 'lib/aws-sdk-inspector2/types.rb', line 2436

def unknown
  @unknown
end