Class: Aws::Inspector2::Types::CodeSnippetResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Contains information on a code snippet retrieved by Amazon Inspector from a code vulnerability finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_snippet ⇒ Array<Types::CodeLine>

Contains information on the retrieved code snippet.

Returns:



2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-inspector2/types.rb', line 2594

class CodeSnippetResult < Struct.new(
  :finding_arn,
  :start_line,
  :end_line,
  :code_snippet,
  :suggested_fixes)
  SENSITIVE = []
  include Aws::Structure
end

#end_line ⇒ Integer

The line number of the last line of a code snippet.

Returns:

  • (Integer)


2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-inspector2/types.rb', line 2594

class CodeSnippetResult < Struct.new(
  :finding_arn,
  :start_line,
  :end_line,
  :code_snippet,
  :suggested_fixes)
  SENSITIVE = []
  include Aws::Structure
end

#finding_arn ⇒ String

The ARN of a finding that the code snippet is associated with.

Returns:

  • (String)


2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-inspector2/types.rb', line 2594

class CodeSnippetResult < Struct.new(
  :finding_arn,
  :start_line,
  :end_line,
  :code_snippet,
  :suggested_fixes)
  SENSITIVE = []
  include Aws::Structure
end

#start_line ⇒ Integer

The line number of the first line of a code snippet.

Returns:

  • (Integer)


2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-inspector2/types.rb', line 2594

class CodeSnippetResult < Struct.new(
  :finding_arn,
  :start_line,
  :end_line,
  :code_snippet,
  :suggested_fixes)
  SENSITIVE = []
  include Aws::Structure
end

#suggested_fixes ⇒ Array<Types::SuggestedFix>

Details of a suggested code fix.

Returns:



2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-inspector2/types.rb', line 2594

class CodeSnippetResult < Struct.new(
  :finding_arn,
  :start_line,
  :end_line,
  :code_snippet,
  :suggested_fixes)
  SENSITIVE = []
  include Aws::Structure
end