Class: Aws::Inspector2::Types::CodeVulnerabilityDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Contains information on the code vulnerability identified in your Lambda function.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cwes ⇒ Array<String>

The Common Weakness Enumeration (CWE) item associated with the detected vulnerability.

Returns:

  • (Array<String>)


2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
# File 'lib/aws-sdk-inspector2/types.rb', line 2666

class CodeVulnerabilityDetails < Struct.new(
  :file_path,
  :detector_tags,
  :reference_urls,
  :rule_id,
  :source_lambda_layer_arn,
  :detector_id,
  :detector_name,
  :cwes)
  SENSITIVE = []
  include Aws::Structure
end

#detector_id ⇒ String

The ID for the Amazon CodeGuru detector associated with the finding. For more information on detectors see Amazon CodeGuru Detector Library.

Returns:

  • (String)


2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
# File 'lib/aws-sdk-inspector2/types.rb', line 2666

class CodeVulnerabilityDetails < Struct.new(
  :file_path,
  :detector_tags,
  :reference_urls,
  :rule_id,
  :source_lambda_layer_arn,
  :detector_id,
  :detector_name,
  :cwes)
  SENSITIVE = []
  include Aws::Structure
end

#detector_name ⇒ String

The name of the detector used to identify the code vulnerability. For more information on detectors see CodeGuru Detector Library.

Returns:

  • (String)


2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
# File 'lib/aws-sdk-inspector2/types.rb', line 2666

class CodeVulnerabilityDetails < Struct.new(
  :file_path,
  :detector_tags,
  :reference_urls,
  :rule_id,
  :source_lambda_layer_arn,
  :detector_id,
  :detector_name,
  :cwes)
  SENSITIVE = []
  include Aws::Structure
end

#detector_tags ⇒ Array<String>

The detector tag associated with the vulnerability. Detector tags group related vulnerabilities by common themes or tactics. For a list of available tags by programming language, see Java tags, or Python tags.

Returns:

  • (Array<String>)


2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
# File 'lib/aws-sdk-inspector2/types.rb', line 2666

class CodeVulnerabilityDetails < Struct.new(
  :file_path,
  :detector_tags,
  :reference_urls,
  :rule_id,
  :source_lambda_layer_arn,
  :detector_id,
  :detector_name,
  :cwes)
  SENSITIVE = []
  include Aws::Structure
end

#file_path ⇒ Types::CodeFilePath

Contains information on where the code vulnerability is located in your code.

Returns:



2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
# File 'lib/aws-sdk-inspector2/types.rb', line 2666

class CodeVulnerabilityDetails < Struct.new(
  :file_path,
  :detector_tags,
  :reference_urls,
  :rule_id,
  :source_lambda_layer_arn,
  :detector_id,
  :detector_name,
  :cwes)
  SENSITIVE = []
  include Aws::Structure
end

#reference_urls ⇒ Array<String>

A URL containing supporting documentation about the code vulnerability detected.

Returns:

  • (Array<String>)


2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
# File 'lib/aws-sdk-inspector2/types.rb', line 2666

class CodeVulnerabilityDetails < Struct.new(
  :file_path,
  :detector_tags,
  :reference_urls,
  :rule_id,
  :source_lambda_layer_arn,
  :detector_id,
  :detector_name,
  :cwes)
  SENSITIVE = []
  include Aws::Structure
end

#rule_id ⇒ String

The identifier for a rule that was used to detect the code vulnerability.

Returns:

  • (String)


2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
# File 'lib/aws-sdk-inspector2/types.rb', line 2666

class CodeVulnerabilityDetails < Struct.new(
  :file_path,
  :detector_tags,
  :reference_urls,
  :rule_id,
  :source_lambda_layer_arn,
  :detector_id,
  :detector_name,
  :cwes)
  SENSITIVE = []
  include Aws::Structure
end

#source_lambda_layer_arn ⇒ String

The Amazon Resource Name (ARN) of the Lambda layer that the code vulnerability was detected in.

Returns:

  • (String)


2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
# File 'lib/aws-sdk-inspector2/types.rb', line 2666

class CodeVulnerabilityDetails < Struct.new(
  :file_path,
  :detector_tags,
  :reference_urls,
  :rule_id,
  :source_lambda_layer_arn,
  :detector_id,
  :detector_name,
  :cwes)
  SENSITIVE = []
  include Aws::Structure
end