Class: Aws::Inspector2::Types::ContainerImageAggregationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

A response that contains the results of a container image aggregation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The account ID associated with the container image.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#architecture ⇒ String

The architecture of the container image.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_account_id ⇒ String

The cloud account ID for the container image aggregation.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_org_id ⇒ String

The cloud organization ID for the container image aggregation.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_partition ⇒ String

The cloud infrastructure partition associated with this container image aggregation. Valid values:

  • aws – Amazon Web Services commercial Regions.

  • aws-cn – Amazon Web Services China Regions.

  • aws-us-gov – Amazon Web Services GovCloud (US) Regions.

  • AzureCloud – Azure commercial Regions.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_provider ⇒ String

The cloud service provider associated with this container image aggregation. Valid values:

  • AWS – Findings from Amazon Web Services resources.

  • AZURE – Findings from Microsoft Azure resources.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_region ⇒ String

The cloud Region associated with this container image aggregation. The value format depends on the cloud provider:

  • An Amazon Web Services Region, such as us-east-1.

  • An Azure region, such as eastus.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#exploit_available_active_findings_count ⇒ Integer

The number of active findings with an exploit available for the container image.

Returns:

  • (Integer)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#fix_available_active_findings_count ⇒ Integer

The number of active findings with a fix available for the container image.

Returns:

  • (Integer)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#image_digest ⇒ String

The image digest for the container image.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#image_tags ⇒ Array<String>

The image tags attached to the container image.

Returns:

  • (Array<String>)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#in_use_count ⇒ Integer

The number of times the container image is in use.

Returns:

  • (Integer)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#last_in_use_at ⇒ Time

The last time the container image was in use.

Returns:



3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#registry ⇒ String

The registry for the container image.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#repository ⇒ String

The repository for the container image.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#resource_id ⇒ String

The resource ID for the container image.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#severity_counts ⇒ Types::SeverityCounts

An object that contains the counts of aggregated finding per severity.



3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-inspector2/types.rb', line 3180

class ContainerImageAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :image_digest,
  :repository,
  :registry,
  :architecture,
  :image_tags,
  :account_id,
  :severity_counts,
  :last_in_use_at,
  :in_use_count,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end