Class: Aws::Inspector2::Types::CoveredResource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

An object that contains details about a resource covered by Amazon Inspector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The Amazon Web Services account ID of the covered resource.

Returns:

  • (String)


3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
# File 'lib/aws-sdk-inspector2/types.rb', line 3632

class CoveredResource < Struct.new(
  :resource_type,
  :resource_id,
  :account_id,
  :scan_type,
  :scan_status,
  :resource_metadata,
  :last_scanned_at,
  :scan_mode,
  :provider,
  :provider_account_id,
  :provider_org_id,
  :provider_region,
  :provider_partition)
  SENSITIVE = []
  include Aws::Structure
end

#last_scanned_at ⇒ Time

The date and time the resource was last checked for vulnerabilities.

Returns:



3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
# File 'lib/aws-sdk-inspector2/types.rb', line 3632

class CoveredResource < Struct.new(
  :resource_type,
  :resource_id,
  :account_id,
  :scan_type,
  :scan_status,
  :resource_metadata,
  :last_scanned_at,
  :scan_mode,
  :provider,
  :provider_account_id,
  :provider_org_id,
  :provider_region,
  :provider_partition)
  SENSITIVE = []
  include Aws::Structure
end

#provider ⇒ String

The cloud provider of the covered resource.

Returns:

  • (String)


3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
# File 'lib/aws-sdk-inspector2/types.rb', line 3632

class CoveredResource < Struct.new(
  :resource_type,
  :resource_id,
  :account_id,
  :scan_type,
  :scan_status,
  :resource_metadata,
  :last_scanned_at,
  :scan_mode,
  :provider,
  :provider_account_id,
  :provider_org_id,
  :provider_region,
  :provider_partition)
  SENSITIVE = []
  include Aws::Structure
end

#provider_account_id ⇒ String

The cloud provider account ID of the covered resource.

Returns:

  • (String)


3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
# File 'lib/aws-sdk-inspector2/types.rb', line 3632

class CoveredResource < Struct.new(
  :resource_type,
  :resource_id,
  :account_id,
  :scan_type,
  :scan_status,
  :resource_metadata,
  :last_scanned_at,
  :scan_mode,
  :provider,
  :provider_account_id,
  :provider_org_id,
  :provider_region,
  :provider_partition)
  SENSITIVE = []
  include Aws::Structure
end

#provider_org_id ⇒ String

The cloud provider organization ID of the covered resource.

Returns:

  • (String)


3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
# File 'lib/aws-sdk-inspector2/types.rb', line 3632

class CoveredResource < Struct.new(
  :resource_type,
  :resource_id,
  :account_id,
  :scan_type,
  :scan_status,
  :resource_metadata,
  :last_scanned_at,
  :scan_mode,
  :provider,
  :provider_account_id,
  :provider_org_id,
  :provider_region,
  :provider_partition)
  SENSITIVE = []
  include Aws::Structure
end

#provider_partition ⇒ String

The cloud provider partition of the covered resource.

Returns:

  • (String)


3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
# File 'lib/aws-sdk-inspector2/types.rb', line 3632

class CoveredResource < Struct.new(
  :resource_type,
  :resource_id,
  :account_id,
  :scan_type,
  :scan_status,
  :resource_metadata,
  :last_scanned_at,
  :scan_mode,
  :provider,
  :provider_account_id,
  :provider_org_id,
  :provider_region,
  :provider_partition)
  SENSITIVE = []
  include Aws::Structure
end

#provider_region ⇒ String

The cloud provider region of the covered resource.

Returns:

  • (String)


3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
# File 'lib/aws-sdk-inspector2/types.rb', line 3632

class CoveredResource < Struct.new(
  :resource_type,
  :resource_id,
  :account_id,
  :scan_type,
  :scan_status,
  :resource_metadata,
  :last_scanned_at,
  :scan_mode,
  :provider,
  :provider_account_id,
  :provider_org_id,
  :provider_region,
  :provider_partition)
  SENSITIVE = []
  include Aws::Structure
end

#resource_id ⇒ String

The ID of the covered resource.

Returns:

  • (String)


3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
# File 'lib/aws-sdk-inspector2/types.rb', line 3632

class CoveredResource < Struct.new(
  :resource_type,
  :resource_id,
  :account_id,
  :scan_type,
  :scan_status,
  :resource_metadata,
  :last_scanned_at,
  :scan_mode,
  :provider,
  :provider_account_id,
  :provider_org_id,
  :provider_region,
  :provider_partition)
  SENSITIVE = []
  include Aws::Structure
end

#resource_metadata ⇒ Types::ResourceScanMetadata

An object that contains details about the metadata.



3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
# File 'lib/aws-sdk-inspector2/types.rb', line 3632

class CoveredResource < Struct.new(
  :resource_type,
  :resource_id,
  :account_id,
  :scan_type,
  :scan_status,
  :resource_metadata,
  :last_scanned_at,
  :scan_mode,
  :provider,
  :provider_account_id,
  :provider_org_id,
  :provider_region,
  :provider_partition)
  SENSITIVE = []
  include Aws::Structure
end

#resource_type ⇒ String

The type of the covered resource.

Returns:

  • (String)


3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
# File 'lib/aws-sdk-inspector2/types.rb', line 3632

class CoveredResource < Struct.new(
  :resource_type,
  :resource_id,
  :account_id,
  :scan_type,
  :scan_status,
  :resource_metadata,
  :last_scanned_at,
  :scan_mode,
  :provider,
  :provider_account_id,
  :provider_org_id,
  :provider_region,
  :provider_partition)
  SENSITIVE = []
  include Aws::Structure
end

#scan_mode ⇒ String

The scan method that is applied to the instance.

Returns:

  • (String)


3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
# File 'lib/aws-sdk-inspector2/types.rb', line 3632

class CoveredResource < Struct.new(
  :resource_type,
  :resource_id,
  :account_id,
  :scan_type,
  :scan_status,
  :resource_metadata,
  :last_scanned_at,
  :scan_mode,
  :provider,
  :provider_account_id,
  :provider_org_id,
  :provider_region,
  :provider_partition)
  SENSITIVE = []
  include Aws::Structure
end

#scan_status ⇒ Types::ScanStatus

The status of the scan covering the resource.

Returns:



3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
# File 'lib/aws-sdk-inspector2/types.rb', line 3632

class CoveredResource < Struct.new(
  :resource_type,
  :resource_id,
  :account_id,
  :scan_type,
  :scan_status,
  :resource_metadata,
  :last_scanned_at,
  :scan_mode,
  :provider,
  :provider_account_id,
  :provider_org_id,
  :provider_region,
  :provider_partition)
  SENSITIVE = []
  include Aws::Structure
end

#scan_type ⇒ String

The Amazon Inspector scan type covering the resource.

Returns:

  • (String)


3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
# File 'lib/aws-sdk-inspector2/types.rb', line 3632

class CoveredResource < Struct.new(
  :resource_type,
  :resource_id,
  :account_id,
  :scan_type,
  :scan_status,
  :resource_metadata,
  :last_scanned_at,
  :scan_mode,
  :provider,
  :provider_account_id,
  :provider_org_id,
  :provider_region,
  :provider_partition)
  SENSITIVE = []
  include Aws::Structure
end