Class: Aws::Inspector2::Types::CreateCodeSecurityIntegrationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#details ⇒ Types::CreateIntegrationDetail

The integration details specific to the repository provider type.



3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-inspector2/types.rb', line 3732

class CreateCodeSecurityIntegrationRequest < Struct.new(
  :name,
  :type,
  :details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the code security integration.

Returns:

  • (String)


3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-inspector2/types.rb', line 3732

class CreateCodeSecurityIntegrationRequest < Struct.new(
  :name,
  :type,
  :details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags to apply to the code security integration.

Returns:

  • (Hash<String,String>)


3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-inspector2/types.rb', line 3732

class CreateCodeSecurityIntegrationRequest < Struct.new(
  :name,
  :type,
  :details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of repository provider for the integration.

Returns:

  • (String)


3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-inspector2/types.rb', line 3732

class CreateCodeSecurityIntegrationRequest < Struct.new(
  :name,
  :type,
  :details,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end