Class: Aws::Inspector2::Types::CreateIntegrationDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Note:

CreateIntegrationDetail is a union - when making an API calls you must set exactly one of the members.

Contains details required to create a code security integration with a specific repository provider.

Defined Under Namespace

Classes: GitlabSelfManaged, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#gitlab_self_managed ⇒ Types::CreateGitLabSelfManagedIntegrationDetail

Details specific to creating an integration with a self-managed GitLab instance.



3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
# File 'lib/aws-sdk-inspector2/types.rb', line 3990

class CreateIntegrationDetail < Struct.new(
  :gitlab_self_managed,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class GitlabSelfManaged < CreateIntegrationDetail; end
  class Unknown < CreateIntegrationDetail; end
end

#unknown ⇒ Object

Returns the value of attribute unknown

Returns:

  • (Object) —

    the current value of unknown



3990
3991
3992
# File 'lib/aws-sdk-inspector2/types.rb', line 3990

def unknown
  @unknown
end