Class: Aws::Inspector2::Types::DelegatedAdmin

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Details of the Amazon Inspector delegated administrator for your organization.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The Amazon Web Services account ID of the Amazon Inspector delegated administrator for your organization.

Returns:

  • (String)


4235
4236
4237
4238
4239
4240
# File 'lib/aws-sdk-inspector2/types.rb', line 4235

class DelegatedAdmin < Struct.new(
  :account_id,
  :relationship_status)
  SENSITIVE = []
  include Aws::Structure
end

#relationship_status ⇒ String

The status of the Amazon Inspector delegated administrator.

Returns:

  • (String)


4235
4236
4237
4238
4239
4240
# File 'lib/aws-sdk-inspector2/types.rb', line 4235

class DelegatedAdmin < Struct.new(
  :account_id,
  :relationship_status)
  SENSITIVE = []
  include Aws::Structure
end