Class: Aws::Inspector2::Types::DelegatedAdminAccount

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Details of the Amazon Inspector delegated administrator for your organization.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The Amazon Web Services account ID of the Amazon Inspector delegated administrator for your organization.

Returns:

  • (String)


4256
4257
4258
4259
4260
4261
# File 'lib/aws-sdk-inspector2/types.rb', line 4256

class DelegatedAdminAccount < Struct.new(
  :account_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the Amazon Inspector delegated administrator.

Returns:

  • (String)


4256
4257
4258
4259
4260
4261
# File 'lib/aws-sdk-inspector2/types.rb', line 4256

class DelegatedAdminAccount < Struct.new(
  :account_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end