Class: Aws::Inspector2::Types::DescribeOrganizationConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_enable ⇒ Types::AutoEnable

The scan types are automatically enabled for new members of your organization.

Returns:



4396
4397
4398
4399
4400
4401
# File 'lib/aws-sdk-inspector2/types.rb', line 4396

class DescribeOrganizationConfigurationResponse < Struct.new(
  :auto_enable,
  :max_account_limit_reached)
  SENSITIVE = []
  include Aws::Structure
end

#max_account_limit_reached ⇒ Boolean

Represents whether your organization has reached the maximum Amazon Web Services account limit for Amazon Inspector.

Returns:

  • (Boolean)


4396
4397
4398
4399
4400
4401
# File 'lib/aws-sdk-inspector2/types.rb', line 4396

class DescribeOrganizationConfigurationResponse < Struct.new(
  :auto_enable,
  :max_account_limit_reached)
  SENSITIVE = []
  include Aws::Structure
end