Class: Aws::Inspector2::Types::Ec2Configuration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Enables agent-based scanning, which scans instances that are not managed by SSM.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activate_vm_scanner ⇒ Boolean

Whether to activate Amazon Inspector VM scanner for Amazon EC2 scanning.

Returns:

  • (Boolean)


4553
4554
4555
4556
4557
4558
# File 'lib/aws-sdk-inspector2/types.rb', line 4553

class Ec2Configuration < Struct.new(
  :scan_mode,
  :activate_vm_scanner)
  SENSITIVE = []
  include Aws::Structure
end

#scan_mode ⇒ String

The scan method that is applied to the instance.

Returns:

  • (String)


4553
4554
4555
4556
4557
4558
# File 'lib/aws-sdk-inspector2/types.rb', line 4553

class Ec2Configuration < Struct.new(
  :scan_mode,
  :activate_vm_scanner)
  SENSITIVE = []
  include Aws::Structure
end