Class: Aws::Inspector2::Types::Ec2ConfigurationState

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Details about the state of the EC2 scan configuration for your environment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#scan_mode_state ⇒ Types::Ec2ScanModeState

An object that contains details about the state of the Amazon EC2 scan mode.



4575
4576
4577
4578
4579
4580
# File 'lib/aws-sdk-inspector2/types.rb', line 4575

class Ec2ConfigurationState < Struct.new(
  :scan_mode_state,
  :vm_scanner_state)
  SENSITIVE = []
  include Aws::Structure
end

#vm_scanner_state ⇒ Types::VMScannerState

An object that contains details about the state of the Amazon Inspector VM scanner.



4575
4576
4577
4578
4579
4580
# File 'lib/aws-sdk-inspector2/types.rb', line 4575

class Ec2ConfigurationState < Struct.new(
  :scan_mode_state,
  :vm_scanner_state)
  SENSITIVE = []
  include Aws::Structure
end