Class: Aws::Inspector2::Types::Ec2InstanceAggregation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

The details that define an aggregation based on Amazon EC2 instances.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amis ⇒ Array<Types::StringFilter>

The AMI IDs associated with the Amazon EC2 instances to aggregate findings for.

Returns:



4613
4614
4615
4616
4617
4618
4619
4620
4621
4622
# File 'lib/aws-sdk-inspector2/types.rb', line 4613

class Ec2InstanceAggregation < Struct.new(
  :amis,
  :operating_systems,
  :instance_ids,
  :instance_tags,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#instance_ids ⇒ Array<Types::StringFilter>

The Amazon EC2 instance IDs to aggregate findings for.

Returns:



4613
4614
4615
4616
4617
4618
4619
4620
4621
4622
# File 'lib/aws-sdk-inspector2/types.rb', line 4613

class Ec2InstanceAggregation < Struct.new(
  :amis,
  :operating_systems,
  :instance_ids,
  :instance_tags,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#instance_tags ⇒ Array<Types::MapFilter>

The Amazon EC2 instance tags to aggregate findings for.

Returns:



4613
4614
4615
4616
4617
4618
4619
4620
4621
4622
# File 'lib/aws-sdk-inspector2/types.rb', line 4613

class Ec2InstanceAggregation < Struct.new(
  :amis,
  :operating_systems,
  :instance_ids,
  :instance_tags,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#operating_systems ⇒ Array<Types::StringFilter>

The operating system types to aggregate findings for. Valid values must be uppercase and underscore separated, examples are ORACLE_LINUX_7 and ALPINE_LINUX_3_8.

Returns:



4613
4614
4615
4616
4617
4618
4619
4620
4621
4622
# File 'lib/aws-sdk-inspector2/types.rb', line 4613

class Ec2InstanceAggregation < Struct.new(
  :amis,
  :operating_systems,
  :instance_ids,
  :instance_tags,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ String

The value to sort results by.

Returns:

  • (String)


4613
4614
4615
4616
4617
4618
4619
4620
4621
4622
# File 'lib/aws-sdk-inspector2/types.rb', line 4613

class Ec2InstanceAggregation < Struct.new(
  :amis,
  :operating_systems,
  :instance_ids,
  :instance_tags,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#sort_order ⇒ String

The order to sort results by.

Returns:

  • (String)


4613
4614
4615
4616
4617
4618
4619
4620
4621
4622
# File 'lib/aws-sdk-inspector2/types.rb', line 4613

class Ec2InstanceAggregation < Struct.new(
  :amis,
  :operating_systems,
  :instance_ids,
  :instance_tags,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end