Class: Aws::Inspector2::Types::Ec2InstanceAggregationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

A response that contains the results of a finding aggregation by Amazon EC2 instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The Amazon Web Services account for the Amazon EC2 instance.

Returns:

  • (String)


4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
# File 'lib/aws-sdk-inspector2/types.rb', line 4657

class Ec2InstanceAggregationResponse < Struct.new(
  :instance_id,
  :ami,
  :operating_system,
  :instance_tags,
  :account_id,
  :severity_counts,
  :network_findings)
  SENSITIVE = []
  include Aws::Structure
end

#ami ⇒ String

The Amazon Machine Image (AMI) of the Amazon EC2 instance.

Returns:

  • (String)


4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
# File 'lib/aws-sdk-inspector2/types.rb', line 4657

class Ec2InstanceAggregationResponse < Struct.new(
  :instance_id,
  :ami,
  :operating_system,
  :instance_tags,
  :account_id,
  :severity_counts,
  :network_findings)
  SENSITIVE = []
  include Aws::Structure
end

#instance_id ⇒ String

The Amazon EC2 instance ID.

Returns:

  • (String)


4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
# File 'lib/aws-sdk-inspector2/types.rb', line 4657

class Ec2InstanceAggregationResponse < Struct.new(
  :instance_id,
  :ami,
  :operating_system,
  :instance_tags,
  :account_id,
  :severity_counts,
  :network_findings)
  SENSITIVE = []
  include Aws::Structure
end

#instance_tags ⇒ Hash<String,String>

The tags attached to the instance.

Returns:

  • (Hash<String,String>)


4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
# File 'lib/aws-sdk-inspector2/types.rb', line 4657

class Ec2InstanceAggregationResponse < Struct.new(
  :instance_id,
  :ami,
  :operating_system,
  :instance_tags,
  :account_id,
  :severity_counts,
  :network_findings)
  SENSITIVE = []
  include Aws::Structure
end

#network_findings ⇒ Integer

The number of network findings for the Amazon EC2 instance.

Returns:

  • (Integer)


4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
# File 'lib/aws-sdk-inspector2/types.rb', line 4657

class Ec2InstanceAggregationResponse < Struct.new(
  :instance_id,
  :ami,
  :operating_system,
  :instance_tags,
  :account_id,
  :severity_counts,
  :network_findings)
  SENSITIVE = []
  include Aws::Structure
end

#operating_system ⇒ String

The operating system of the Amazon EC2 instance.

Returns:

  • (String)


4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
# File 'lib/aws-sdk-inspector2/types.rb', line 4657

class Ec2InstanceAggregationResponse < Struct.new(
  :instance_id,
  :ami,
  :operating_system,
  :instance_tags,
  :account_id,
  :severity_counts,
  :network_findings)
  SENSITIVE = []
  include Aws::Structure
end

#severity_counts ⇒ Types::SeverityCounts

An object that contains the count of matched findings per severity.



4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
# File 'lib/aws-sdk-inspector2/types.rb', line 4657

class Ec2InstanceAggregationResponse < Struct.new(
  :instance_id,
  :ami,
  :operating_system,
  :instance_tags,
  :account_id,
  :severity_counts,
  :network_findings)
  SENSITIVE = []
  include Aws::Structure
end