Class: Aws::Inspector2::Types::EnableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_ids ⇒ Array<String>

A list of account IDs you want to enable Amazon Inspector scans for.

Returns:

  • (Array<String>)


4897
4898
4899
4900
4901
4902
4903
# File 'lib/aws-sdk-inspector2/types.rb', line 4897

class EnableRequest < Struct.new(
  :account_ids,
  :resource_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_token ⇒ String

The idempotency token for the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


4897
4898
4899
4900
4901
4902
4903
# File 'lib/aws-sdk-inspector2/types.rb', line 4897

class EnableRequest < Struct.new(
  :account_ids,
  :resource_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_types ⇒ Array<String>

The resource scan types you want to enable.

Returns:

  • (Array<String>)


4897
4898
4899
4900
4901
4902
4903
# File 'lib/aws-sdk-inspector2/types.rb', line 4897

class EnableRequest < Struct.new(
  :account_ids,
  :resource_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end