Class: Aws::Inspector2::Types::ExploitObserved
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::ExploitObserved
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
Contains information on when this exploit was observed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#first_seen ⇒ Time
The date an time when the exploit was first seen.
-
#last_seen ⇒ Time
The date an time when the exploit was last seen.
Instance Attribute Details
#first_seen ⇒ Time
The date an time when the exploit was first seen.
4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-inspector2/types.rb', line 4989 class ExploitObserved < Struct.new( :last_seen, :first_seen) SENSITIVE = [] include Aws::Structure end |
#last_seen ⇒ Time
The date an time when the exploit was last seen.
4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-inspector2/types.rb', line 4989 class ExploitObserved < Struct.new( :last_seen, :first_seen) SENSITIVE = [] include Aws::Structure end |