Class: Aws::Inspector2::Types::ExploitabilityDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

The details of an exploit available for a finding discovered in your environment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_known_exploit_at ⇒ Time

The date and time of the last exploit associated with a finding discovered in your environment.

Returns:



5006
5007
5008
5009
5010
# File 'lib/aws-sdk-inspector2/types.rb', line 5006

class ExploitabilityDetails < Struct.new(
  :last_known_exploit_at)
  SENSITIVE = []
  include Aws::Structure
end