Class: Aws::Inspector2::Types::Finding
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::Finding
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
Details about an Amazon Inspector finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID associated with the finding.
-
#code_vulnerability_details ⇒ Types::CodeVulnerabilityDetails
Details about the code vulnerability identified in a Lambda function used to filter findings.
-
#description ⇒ String
The description of the finding.
-
#epss ⇒ Types::EpssDetails
The finding's EPSS score.
-
#exploit_available ⇒ String
If a finding discovered in your environment has an exploit available.
-
#exploitability_details ⇒ Types::ExploitabilityDetails
The details of an exploit available for a finding discovered in your environment.
-
#finding_arn ⇒ String
The Amazon Resource Number (ARN) of the finding.
-
#first_observed_at ⇒ Time
The date and time that the finding was first observed.
-
#fix_available ⇒ String
Details on whether a fix is available through a version update.
-
#inspector_score ⇒ Float
The Amazon Inspector score given to the finding.
-
#inspector_score_details ⇒ Types::InspectorScoreDetails
An object that contains details of the Amazon Inspector score.
-
#last_observed_at ⇒ Time
The date and time the finding was last observed.
-
#network_reachability_details ⇒ Types::NetworkReachabilityDetails
An object that contains the details of a network reachability finding.
-
#package_vulnerability_details ⇒ Types::PackageVulnerabilityDetails
An object that contains the details of a package vulnerability finding.
-
#remediation ⇒ Types::Remediation
An object that contains the details about how to remediate a finding.
-
#resources ⇒ Array<Types::Resource>
Contains information on the resources involved in a finding.
-
#severity ⇒ String
The severity of the finding.
-
#status ⇒ String
The status of the finding.
-
#title ⇒ String
The title of the finding.
-
#type ⇒ String
The type of the finding.
-
#updated_at ⇒ Time
The date and time the finding was last updated at.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID associated with the finding.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#code_vulnerability_details ⇒ Types::CodeVulnerabilityDetails
Details about the code vulnerability identified in a Lambda function used to filter findings.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the finding.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#epss ⇒ Types::EpssDetails
The finding's EPSS score.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#exploit_available ⇒ String
If a finding discovered in your environment has an exploit available.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#exploitability_details ⇒ Types::ExploitabilityDetails
The details of an exploit available for a finding discovered in your environment.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#finding_arn ⇒ String
The Amazon Resource Number (ARN) of the finding.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#first_observed_at ⇒ Time
The date and time that the finding was first observed.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#fix_available ⇒ String
Details on whether a fix is available through a version update. This
value can be YES, NO, or PARTIAL. A PARTIAL fix means that
some, but not all, of the packages identified in the finding have
fixes available through updated versions.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#inspector_score ⇒ Float
The Amazon Inspector score given to the finding.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#inspector_score_details ⇒ Types::InspectorScoreDetails
An object that contains details of the Amazon Inspector score.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#last_observed_at ⇒ Time
The date and time the finding was last observed. This timestamp for this field remains unchanged until a finding is updated.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#network_reachability_details ⇒ Types::NetworkReachabilityDetails
An object that contains the details of a network reachability finding.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#package_vulnerability_details ⇒ Types::PackageVulnerabilityDetails
An object that contains the details of a package vulnerability finding.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#remediation ⇒ Types::Remediation
An object that contains the details about how to remediate a finding.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<Types::Resource>
Contains information on the resources involved in a finding. The
resource value determines the valid values for type in your
request. For more information, see Finding types in the Amazon
Inspector user guide.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ String
The severity of the finding. UNTRIAGED applies to
PACKAGE_VULNERABILITY type findings that the vendor has not
assigned a severity yet. For more information, see Severity levels
for findings in the Amazon Inspector user guide.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the finding.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the finding.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the finding. The type value determines the valid
values for resource in your request. For more information, see
Finding types in the Amazon Inspector user guide.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the finding was last updated at.
5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5667 class Finding < Struct.new( :finding_arn, :aws_account_id, :type, :description, :title, :remediation, :severity, :first_observed_at, :last_observed_at, :updated_at, :status, :resources, :inspector_score, :inspector_score_details, :network_reachability_details, :package_vulnerability_details, :fix_available, :exploit_available, :exploitability_details, :code_vulnerability_details, :epss) SENSITIVE = [] include Aws::Structure end |