Class: Aws::Inspector2::Types::FreeTrialInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

An object that contains information about the Amazon Inspector free trial for an account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_provider ⇒ String

The cloud provider associated with the free trial information.

Returns:

  • (String)


5932
5933
5934
5935
5936
5937
5938
5939
5940
# File 'lib/aws-sdk-inspector2/types.rb', line 5932

class FreeTrialInfo < Struct.new(
  :type,
  :start,
  :end,
  :status,
  :cloud_provider)
  SENSITIVE = []
  include Aws::Structure
end

#end ⇒ Time

The date and time that the Amazon Inspector free trail ends for a given account.

Returns:



5932
5933
5934
5935
5936
5937
5938
5939
5940
# File 'lib/aws-sdk-inspector2/types.rb', line 5932

class FreeTrialInfo < Struct.new(
  :type,
  :start,
  :end,
  :status,
  :cloud_provider)
  SENSITIVE = []
  include Aws::Structure
end

#start ⇒ Time

The date and time that the Amazon Inspector free trail started for a given account.

Returns:



5932
5933
5934
5935
5936
5937
5938
5939
5940
# File 'lib/aws-sdk-inspector2/types.rb', line 5932

class FreeTrialInfo < Struct.new(
  :type,
  :start,
  :end,
  :status,
  :cloud_provider)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The order to sort results by.

Returns:

  • (String)


5932
5933
5934
5935
5936
5937
5938
5939
5940
# File 'lib/aws-sdk-inspector2/types.rb', line 5932

class FreeTrialInfo < Struct.new(
  :type,
  :start,
  :end,
  :status,
  :cloud_provider)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of scan covered by the Amazon Inspector free trail.

Returns:

  • (String)


5932
5933
5934
5935
5936
5937
5938
5939
5940
# File 'lib/aws-sdk-inspector2/types.rb', line 5932

class FreeTrialInfo < Struct.new(
  :type,
  :start,
  :end,
  :status,
  :cloud_provider)
  SENSITIVE = []
  include Aws::Structure
end