Class: Aws::Inspector2::Types::GetCisScanResultDetailsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::GetCisScanResultDetailsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account ID.
-
#filter_criteria ⇒ Types::CisScanResultDetailsFilterCriteria
The filter criteria.
-
#max_results ⇒ Integer
The maximum number of CIS scan result details to be returned in a single page of results.
-
#next_token ⇒ String
The pagination token from a previous request that's used to retrieve the next page of results.
-
#scan_arn ⇒ String
The scan ARN.
-
#sort_by ⇒ String
The sort by order.
-
#sort_order ⇒ String
The sort order.
-
#target_resource_id ⇒ String
The target resource ID.
Instance Attribute Details
#account_id ⇒ String
The account ID.
6044 6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6044 class GetCisScanResultDetailsRequest < Struct.new( :scan_arn, :target_resource_id, :account_id, :filter_criteria, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#filter_criteria ⇒ Types::CisScanResultDetailsFilterCriteria
The filter criteria.
6044 6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6044 class GetCisScanResultDetailsRequest < Struct.new( :scan_arn, :target_resource_id, :account_id, :filter_criteria, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of CIS scan result details to be returned in a single page of results.
6044 6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6044 class GetCisScanResultDetailsRequest < Struct.new( :scan_arn, :target_resource_id, :account_id, :filter_criteria, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token from a previous request that's used to retrieve the next page of results.
6044 6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6044 class GetCisScanResultDetailsRequest < Struct.new( :scan_arn, :target_resource_id, :account_id, :filter_criteria, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#scan_arn ⇒ String
The scan ARN.
6044 6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6044 class GetCisScanResultDetailsRequest < Struct.new( :scan_arn, :target_resource_id, :account_id, :filter_criteria, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The sort by order.
6044 6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6044 class GetCisScanResultDetailsRequest < Struct.new( :scan_arn, :target_resource_id, :account_id, :filter_criteria, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order.
6044 6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6044 class GetCisScanResultDetailsRequest < Struct.new( :scan_arn, :target_resource_id, :account_id, :filter_criteria, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#target_resource_id ⇒ String
The target resource ID.
6044 6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6044 class GetCisScanResultDetailsRequest < Struct.new( :scan_arn, :target_resource_id, :account_id, :filter_criteria, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |