Class: Aws::Inspector2::Types::GetCodeSecurityIntegrationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:authorization_url]

Instance Attribute Summary collapse

Instance Attribute Details

#authorization_url ⇒ String

The URL used to authorize the integration with the repository provider. This is only returned if reauthorization is required to fix a connection issue. Otherwise, it is null.

Returns:

  • (String)


6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
# File 'lib/aws-sdk-inspector2/types.rb', line 6176

class GetCodeSecurityIntegrationResponse < Struct.new(
  :integration_arn,
  :name,
  :type,
  :status,
  :status_reason,
  :created_on,
  :last_update_on,
  :authorization_url,
  :tags)
  SENSITIVE = [:authorization_url]
  include Aws::Structure
end

#created_on ⇒ Time

The timestamp when the code security integration was created.

Returns:



6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
# File 'lib/aws-sdk-inspector2/types.rb', line 6176

class GetCodeSecurityIntegrationResponse < Struct.new(
  :integration_arn,
  :name,
  :type,
  :status,
  :status_reason,
  :created_on,
  :last_update_on,
  :authorization_url,
  :tags)
  SENSITIVE = [:authorization_url]
  include Aws::Structure
end

#integration_arn ⇒ String

The Amazon Resource Name (ARN) of the code security integration.

Returns:

  • (String)


6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
# File 'lib/aws-sdk-inspector2/types.rb', line 6176

class GetCodeSecurityIntegrationResponse < Struct.new(
  :integration_arn,
  :name,
  :type,
  :status,
  :status_reason,
  :created_on,
  :last_update_on,
  :authorization_url,
  :tags)
  SENSITIVE = [:authorization_url]
  include Aws::Structure
end

#last_update_on ⇒ Time

The timestamp when the code security integration was last updated.

Returns:



6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
# File 'lib/aws-sdk-inspector2/types.rb', line 6176

class GetCodeSecurityIntegrationResponse < Struct.new(
  :integration_arn,
  :name,
  :type,
  :status,
  :status_reason,
  :created_on,
  :last_update_on,
  :authorization_url,
  :tags)
  SENSITIVE = [:authorization_url]
  include Aws::Structure
end

#name ⇒ String

The name of the code security integration.

Returns:

  • (String)


6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
# File 'lib/aws-sdk-inspector2/types.rb', line 6176

class GetCodeSecurityIntegrationResponse < Struct.new(
  :integration_arn,
  :name,
  :type,
  :status,
  :status_reason,
  :created_on,
  :last_update_on,
  :authorization_url,
  :tags)
  SENSITIVE = [:authorization_url]
  include Aws::Structure
end

#status ⇒ String

The current status of the code security integration.

Returns:

  • (String)


6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
# File 'lib/aws-sdk-inspector2/types.rb', line 6176

class GetCodeSecurityIntegrationResponse < Struct.new(
  :integration_arn,
  :name,
  :type,
  :status,
  :status_reason,
  :created_on,
  :last_update_on,
  :authorization_url,
  :tags)
  SENSITIVE = [:authorization_url]
  include Aws::Structure
end

#status_reason ⇒ String

The reason for the current status of the code security integration.

Returns:

  • (String)


6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
# File 'lib/aws-sdk-inspector2/types.rb', line 6176

class GetCodeSecurityIntegrationResponse < Struct.new(
  :integration_arn,
  :name,
  :type,
  :status,
  :status_reason,
  :created_on,
  :last_update_on,
  :authorization_url,
  :tags)
  SENSITIVE = [:authorization_url]
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags associated with the code security integration.

Returns:

  • (Hash<String,String>)


6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
# File 'lib/aws-sdk-inspector2/types.rb', line 6176

class GetCodeSecurityIntegrationResponse < Struct.new(
  :integration_arn,
  :name,
  :type,
  :status,
  :status_reason,
  :created_on,
  :last_update_on,
  :authorization_url,
  :tags)
  SENSITIVE = [:authorization_url]
  include Aws::Structure
end

#type ⇒ String

The type of repository provider for the integration.

Returns:

  • (String)


6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
# File 'lib/aws-sdk-inspector2/types.rb', line 6176

class GetCodeSecurityIntegrationResponse < Struct.new(
  :integration_arn,
  :name,
  :type,
  :status,
  :status_reason,
  :created_on,
  :last_update_on,
  :authorization_url,
  :tags)
  SENSITIVE = [:authorization_url]
  include Aws::Structure
end