Class: Aws::Inspector2::Types::GetCodeSecurityScanConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::GetCodeSecurityScanConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Types::CodeSecurityScanConfiguration
The configuration settings for the code security scan.
-
#created_at ⇒ Time
The timestamp when the scan configuration was created.
-
#last_updated_at ⇒ Time
The timestamp when the scan configuration was last updated.
-
#level ⇒ String
The security level for the scan configuration.
-
#name ⇒ String
The name of the scan configuration.
-
#scan_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the scan configuration.
-
#scope_settings ⇒ Types::ScopeSettings
The scope settings that define which repositories will be scanned.
-
#tags ⇒ Hash<String,String>
The tags associated with the scan configuration.
Instance Attribute Details
#configuration ⇒ Types::CodeSecurityScanConfiguration
The configuration settings for the code security scan.
6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6240 class GetCodeSecurityScanConfigurationResponse < Struct.new( :scan_configuration_arn, :name, :configuration, :level, :scope_settings, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the scan configuration was created.
6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6240 class GetCodeSecurityScanConfigurationResponse < Struct.new( :scan_configuration_arn, :name, :configuration, :level, :scope_settings, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp when the scan configuration was last updated.
6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6240 class GetCodeSecurityScanConfigurationResponse < Struct.new( :scan_configuration_arn, :name, :configuration, :level, :scope_settings, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#level ⇒ String
The security level for the scan configuration.
6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6240 class GetCodeSecurityScanConfigurationResponse < Struct.new( :scan_configuration_arn, :name, :configuration, :level, :scope_settings, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the scan configuration.
6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6240 class GetCodeSecurityScanConfigurationResponse < Struct.new( :scan_configuration_arn, :name, :configuration, :level, :scope_settings, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#scan_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the scan configuration.
6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6240 class GetCodeSecurityScanConfigurationResponse < Struct.new( :scan_configuration_arn, :name, :configuration, :level, :scope_settings, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#scope_settings ⇒ Types::ScopeSettings
The scope settings that define which repositories will be scanned.
If the ScopeSetting parameter is ALL the scan configuration
applies to all existing and future projects imported into Amazon
Inspector.
6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6240 class GetCodeSecurityScanConfigurationResponse < Struct.new( :scan_configuration_arn, :name, :configuration, :level, :scope_settings, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags associated with the scan configuration.
6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6240 class GetCodeSecurityScanConfigurationResponse < Struct.new( :scan_configuration_arn, :name, :configuration, :level, :scope_settings, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |