Class: Aws::Inspector2::Types::GetCodeSecurityScanRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::GetCodeSecurityScanRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource ⇒ Types::CodeSecurityResource
The resource identifier for the code repository that was scanned.
-
#scan_id ⇒ String
The unique identifier of the scan to retrieve.
Instance Attribute Details
#resource ⇒ Types::CodeSecurityResource
The resource identifier for the code repository that was scanned.
6263 6264 6265 6266 6267 6268 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6263 class GetCodeSecurityScanRequest < Struct.new( :resource, :scan_id) SENSITIVE = [] include Aws::Structure end |
#scan_id ⇒ String
The unique identifier of the scan to retrieve.
6263 6264 6265 6266 6267 6268 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6263 class GetCodeSecurityScanRequest < Struct.new( :resource, :scan_id) SENSITIVE = [] include Aws::Structure end |