Class: Aws::Inspector2::Types::GetConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The 12-digit Amazon Web Services account ID of the member account whose scan configuration you want to retrieve. When specified, you must be the delegated administrator for this member account. If not specified, the operation returns your own configuration.

Returns:

  • (String)


6327
6328
6329
6330
6331
# File 'lib/aws-sdk-inspector2/types.rb', line 6327

class GetConfigurationRequest < Struct.new(
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end