Class: Aws::Inspector2::Types::GetEc2DeepInspectionConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_message ⇒ String

An error message explaining why Amazon Inspector deep inspection configurations could not be retrieved for your account.

Returns:

  • (String)


6398
6399
6400
6401
6402
6403
6404
6405
# File 'lib/aws-sdk-inspector2/types.rb', line 6398

class GetEc2DeepInspectionConfigurationResponse < Struct.new(
  :package_paths,
  :org_package_paths,
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#org_package_paths ⇒ Array<String>

The Amazon Inspector deep inspection custom paths for your organization.

Returns:

  • (Array<String>)


6398
6399
6400
6401
6402
6403
6404
6405
# File 'lib/aws-sdk-inspector2/types.rb', line 6398

class GetEc2DeepInspectionConfigurationResponse < Struct.new(
  :package_paths,
  :org_package_paths,
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#package_paths ⇒ Array<String>

The Amazon Inspector deep inspection custom paths for your account.

Returns:

  • (Array<String>)


6398
6399
6400
6401
6402
6403
6404
6405
# File 'lib/aws-sdk-inspector2/types.rb', line 6398

class GetEc2DeepInspectionConfigurationResponse < Struct.new(
  :package_paths,
  :org_package_paths,
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The activation status of Amazon Inspector deep inspection in your account.

Returns:

  • (String)


6398
6399
6400
6401
6402
6403
6404
6405
# File 'lib/aws-sdk-inspector2/types.rb', line 6398

class GetEc2DeepInspectionConfigurationResponse < Struct.new(
  :package_paths,
  :org_package_paths,
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end