Class: Aws::Inspector2::Types::Image

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Contains details about a container image involved in a finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#architecture ⇒ String

The architecture of the container image.

Returns:

  • (String)


6610
6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
6621
6622
6623
# File 'lib/aws-sdk-inspector2/types.rb', line 6610

class Image < Struct.new(
  :repository_name,
  :registry,
  :image_tags,
  :image_digest,
  :pushed_at,
  :architecture,
  :author,
  :in_use_count,
  :last_in_use_at,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#author ⇒ String

The author of the container image.

Returns:

  • (String)


6610
6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
6621
6622
6623
# File 'lib/aws-sdk-inspector2/types.rb', line 6610

class Image < Struct.new(
  :repository_name,
  :registry,
  :image_tags,
  :image_digest,
  :pushed_at,
  :architecture,
  :author,
  :in_use_count,
  :last_in_use_at,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#image_digest ⇒ String

The image digest of the container image.

Returns:

  • (String)


6610
6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
6621
6622
6623
# File 'lib/aws-sdk-inspector2/types.rb', line 6610

class Image < Struct.new(
  :repository_name,
  :registry,
  :image_tags,
  :image_digest,
  :pushed_at,
  :architecture,
  :author,
  :in_use_count,
  :last_in_use_at,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#image_tags ⇒ Array<String>

The image tags attached to the container image.

Returns:

  • (Array<String>)


6610
6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
6621
6622
6623
# File 'lib/aws-sdk-inspector2/types.rb', line 6610

class Image < Struct.new(
  :repository_name,
  :registry,
  :image_tags,
  :image_digest,
  :pushed_at,
  :architecture,
  :author,
  :in_use_count,
  :last_in_use_at,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#in_use_count ⇒ Integer

The number of times the container image is in use.

Returns:

  • (Integer)


6610
6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
6621
6622
6623
# File 'lib/aws-sdk-inspector2/types.rb', line 6610

class Image < Struct.new(
  :repository_name,
  :registry,
  :image_tags,
  :image_digest,
  :pushed_at,
  :architecture,
  :author,
  :in_use_count,
  :last_in_use_at,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#last_in_use_at ⇒ Time

The last time the container image was in use.

Returns:



6610
6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
6621
6622
6623
# File 'lib/aws-sdk-inspector2/types.rb', line 6610

class Image < Struct.new(
  :repository_name,
  :registry,
  :image_tags,
  :image_digest,
  :pushed_at,
  :architecture,
  :author,
  :in_use_count,
  :last_in_use_at,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#platform ⇒ String

The platform of the container image.

Returns:

  • (String)


6610
6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
6621
6622
6623
# File 'lib/aws-sdk-inspector2/types.rb', line 6610

class Image < Struct.new(
  :repository_name,
  :registry,
  :image_tags,
  :image_digest,
  :pushed_at,
  :architecture,
  :author,
  :in_use_count,
  :last_in_use_at,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#pushed_at ⇒ Time

The date and time the container image was pushed.

Returns:



6610
6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
6621
6622
6623
# File 'lib/aws-sdk-inspector2/types.rb', line 6610

class Image < Struct.new(
  :repository_name,
  :registry,
  :image_tags,
  :image_digest,
  :pushed_at,
  :architecture,
  :author,
  :in_use_count,
  :last_in_use_at,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#registry ⇒ String

The registry for the container image.

Returns:

  • (String)


6610
6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
6621
6622
6623
# File 'lib/aws-sdk-inspector2/types.rb', line 6610

class Image < Struct.new(
  :repository_name,
  :registry,
  :image_tags,
  :image_digest,
  :pushed_at,
  :architecture,
  :author,
  :in_use_count,
  :last_in_use_at,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#repository_name ⇒ String

The name of the repository the container image resides in.

Returns:

  • (String)


6610
6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
6621
6622
6623
# File 'lib/aws-sdk-inspector2/types.rb', line 6610

class Image < Struct.new(
  :repository_name,
  :registry,
  :image_tags,
  :image_digest,
  :pushed_at,
  :architecture,
  :author,
  :in_use_count,
  :last_in_use_at,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end