Class: Aws::Inspector2::Types::ImageLayerAggregation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::ImageLayerAggregation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
The details that define an aggregation based on container image layers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_account_ids ⇒ Array<Types::StringFilter>
The cloud account IDs to aggregate findings for.
-
#cloud_org_ids ⇒ Array<Types::StringFilter>
The cloud organization IDs to aggregate findings for.
-
#cloud_partitions ⇒ Array<Types::StringFilter>
The cloud partitions to aggregate findings for.
-
#cloud_providers ⇒ Array<Types::StringFilter>
The cloud providers to aggregate findings for.
-
#cloud_regions ⇒ Array<Types::StringFilter>
The cloud regions to aggregate findings for.
-
#layer_hashes ⇒ Array<Types::StringFilter>
The hashes associated with the layers.
-
#repositories ⇒ Array<Types::StringFilter>
The repository associated with the container image hosting the layers.
-
#resource_ids ⇒ Array<Types::StringFilter>
The ID of the container image layer.
-
#sort_by ⇒ String
The value to sort results by.
-
#sort_order ⇒ String
The order to sort results by.
Instance Attribute Details
#cloud_account_ids ⇒ Array<Types::StringFilter>
The cloud account IDs to aggregate findings for.
6688 6689 6690 6691 6692 6693 6694 6695 6696 6697 6698 6699 6700 6701 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6688 class ImageLayerAggregation < Struct.new( :repositories, :resource_ids, :layer_hashes, :cloud_providers, :cloud_account_ids, :cloud_org_ids, :cloud_regions, :cloud_partitions, :sort_order, :sort_by) SENSITIVE = [] include Aws::Structure end |
#cloud_org_ids ⇒ Array<Types::StringFilter>
The cloud organization IDs to aggregate findings for.
6688 6689 6690 6691 6692 6693 6694 6695 6696 6697 6698 6699 6700 6701 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6688 class ImageLayerAggregation < Struct.new( :repositories, :resource_ids, :layer_hashes, :cloud_providers, :cloud_account_ids, :cloud_org_ids, :cloud_regions, :cloud_partitions, :sort_order, :sort_by) SENSITIVE = [] include Aws::Structure end |
#cloud_partitions ⇒ Array<Types::StringFilter>
The cloud partitions to aggregate findings for. Valid values:
-
aws– Amazon Web Services commercial Regions. -
aws-cn– Amazon Web Services China Regions. -
aws-us-gov– Amazon Web Services GovCloud (US) Regions. -
AzureCloud– Azure commercial Regions.
6688 6689 6690 6691 6692 6693 6694 6695 6696 6697 6698 6699 6700 6701 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6688 class ImageLayerAggregation < Struct.new( :repositories, :resource_ids, :layer_hashes, :cloud_providers, :cloud_account_ids, :cloud_org_ids, :cloud_regions, :cloud_partitions, :sort_order, :sort_by) SENSITIVE = [] include Aws::Structure end |
#cloud_providers ⇒ Array<Types::StringFilter>
The cloud providers to aggregate findings for. Valid values:
-
AWS– Findings from Amazon Web Services resources. -
AZURE– Findings from Microsoft Azure resources.
6688 6689 6690 6691 6692 6693 6694 6695 6696 6697 6698 6699 6700 6701 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6688 class ImageLayerAggregation < Struct.new( :repositories, :resource_ids, :layer_hashes, :cloud_providers, :cloud_account_ids, :cloud_org_ids, :cloud_regions, :cloud_partitions, :sort_order, :sort_by) SENSITIVE = [] include Aws::Structure end |
#cloud_regions ⇒ Array<Types::StringFilter>
The cloud regions to aggregate findings for. The value format depends on the cloud provider:
-
An Amazon Web Services Region, such as
us-east-1. -
An Azure region, such as
eastus.
6688 6689 6690 6691 6692 6693 6694 6695 6696 6697 6698 6699 6700 6701 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6688 class ImageLayerAggregation < Struct.new( :repositories, :resource_ids, :layer_hashes, :cloud_providers, :cloud_account_ids, :cloud_org_ids, :cloud_regions, :cloud_partitions, :sort_order, :sort_by) SENSITIVE = [] include Aws::Structure end |
#layer_hashes ⇒ Array<Types::StringFilter>
The hashes associated with the layers.
6688 6689 6690 6691 6692 6693 6694 6695 6696 6697 6698 6699 6700 6701 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6688 class ImageLayerAggregation < Struct.new( :repositories, :resource_ids, :layer_hashes, :cloud_providers, :cloud_account_ids, :cloud_org_ids, :cloud_regions, :cloud_partitions, :sort_order, :sort_by) SENSITIVE = [] include Aws::Structure end |
#repositories ⇒ Array<Types::StringFilter>
The repository associated with the container image hosting the layers.
6688 6689 6690 6691 6692 6693 6694 6695 6696 6697 6698 6699 6700 6701 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6688 class ImageLayerAggregation < Struct.new( :repositories, :resource_ids, :layer_hashes, :cloud_providers, :cloud_account_ids, :cloud_org_ids, :cloud_regions, :cloud_partitions, :sort_order, :sort_by) SENSITIVE = [] include Aws::Structure end |
#resource_ids ⇒ Array<Types::StringFilter>
The ID of the container image layer.
6688 6689 6690 6691 6692 6693 6694 6695 6696 6697 6698 6699 6700 6701 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6688 class ImageLayerAggregation < Struct.new( :repositories, :resource_ids, :layer_hashes, :cloud_providers, :cloud_account_ids, :cloud_org_ids, :cloud_regions, :cloud_partitions, :sort_order, :sort_by) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The value to sort results by.
6688 6689 6690 6691 6692 6693 6694 6695 6696 6697 6698 6699 6700 6701 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6688 class ImageLayerAggregation < Struct.new( :repositories, :resource_ids, :layer_hashes, :cloud_providers, :cloud_account_ids, :cloud_org_ids, :cloud_regions, :cloud_partitions, :sort_order, :sort_by) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The order to sort results by.
6688 6689 6690 6691 6692 6693 6694 6695 6696 6697 6698 6699 6700 6701 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6688 class ImageLayerAggregation < Struct.new( :repositories, :resource_ids, :layer_hashes, :cloud_providers, :cloud_account_ids, :cloud_org_ids, :cloud_regions, :cloud_partitions, :sort_order, :sort_by) SENSITIVE = [] include Aws::Structure end |