Class: Aws::Inspector2::Types::ImageLayerAggregationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

A response that contains the results of a finding aggregation by image layer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The ID of the Amazon Web Services account that owns the container image hosting the layer image.

Returns:

  • (String)


6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
# File 'lib/aws-sdk-inspector2/types.rb', line 6769

class ImageLayerAggregationResponse < Struct.new(
  :repository,
  :resource_id,
  :layer_hash,
  :account_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_org_id,
  :cloud_region,
  :cloud_partition,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_account_id ⇒ String

The cloud account ID for the image layer aggregation.

Returns:

  • (String)


6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
# File 'lib/aws-sdk-inspector2/types.rb', line 6769

class ImageLayerAggregationResponse < Struct.new(
  :repository,
  :resource_id,
  :layer_hash,
  :account_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_org_id,
  :cloud_region,
  :cloud_partition,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_org_id ⇒ String

The cloud organization ID for the image layer aggregation.

Returns:

  • (String)


6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
# File 'lib/aws-sdk-inspector2/types.rb', line 6769

class ImageLayerAggregationResponse < Struct.new(
  :repository,
  :resource_id,
  :layer_hash,
  :account_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_org_id,
  :cloud_region,
  :cloud_partition,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_partition ⇒ String

The cloud infrastructure partition associated with this image layer aggregation. Valid values:

  • aws – Amazon Web Services commercial Regions.

  • aws-cn – Amazon Web Services China Regions.

  • aws-us-gov – Amazon Web Services GovCloud (US) Regions.

  • AzureCloud – Azure commercial Regions.

Returns:

  • (String)


6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
# File 'lib/aws-sdk-inspector2/types.rb', line 6769

class ImageLayerAggregationResponse < Struct.new(
  :repository,
  :resource_id,
  :layer_hash,
  :account_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_org_id,
  :cloud_region,
  :cloud_partition,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_provider ⇒ String

The cloud service provider associated with this image layer aggregation. Valid values:

  • AWS – Findings from Amazon Web Services resources.

  • AZURE – Findings from Microsoft Azure resources.

Returns:

  • (String)


6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
# File 'lib/aws-sdk-inspector2/types.rb', line 6769

class ImageLayerAggregationResponse < Struct.new(
  :repository,
  :resource_id,
  :layer_hash,
  :account_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_org_id,
  :cloud_region,
  :cloud_partition,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_region ⇒ String

The cloud Region associated with this image layer aggregation. The value format depends on the cloud provider:

  • An Amazon Web Services Region, such as us-east-1.

  • An Azure region, such as eastus.

Returns:

  • (String)


6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
# File 'lib/aws-sdk-inspector2/types.rb', line 6769

class ImageLayerAggregationResponse < Struct.new(
  :repository,
  :resource_id,
  :layer_hash,
  :account_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_org_id,
  :cloud_region,
  :cloud_partition,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#layer_hash ⇒ String

The layer hash.

Returns:

  • (String)


6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
# File 'lib/aws-sdk-inspector2/types.rb', line 6769

class ImageLayerAggregationResponse < Struct.new(
  :repository,
  :resource_id,
  :layer_hash,
  :account_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_org_id,
  :cloud_region,
  :cloud_partition,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#repository ⇒ String

The repository the layer resides in.

Returns:

  • (String)


6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
# File 'lib/aws-sdk-inspector2/types.rb', line 6769

class ImageLayerAggregationResponse < Struct.new(
  :repository,
  :resource_id,
  :layer_hash,
  :account_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_org_id,
  :cloud_region,
  :cloud_partition,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#resource_id ⇒ String

The resource ID of the container image layer.

Returns:

  • (String)


6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
# File 'lib/aws-sdk-inspector2/types.rb', line 6769

class ImageLayerAggregationResponse < Struct.new(
  :repository,
  :resource_id,
  :layer_hash,
  :account_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_org_id,
  :cloud_region,
  :cloud_partition,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#severity_counts ⇒ Types::SeverityCounts

An object that represents the count of matched findings per severity.



6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
# File 'lib/aws-sdk-inspector2/types.rb', line 6769

class ImageLayerAggregationResponse < Struct.new(
  :repository,
  :resource_id,
  :layer_hash,
  :account_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_org_id,
  :cloud_region,
  :cloud_partition,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end