Class: Aws::Inspector2::Types::LambdaFunctionAggregation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

The details that define a findings aggregation based on Amazon Web Services Lambda functions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#function_names ⇒ Array<Types::StringFilter>

The Amazon Web Services Lambda function names to include in the aggregation results.

Returns:



6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
# File 'lib/aws-sdk-inspector2/types.rb', line 6849

class LambdaFunctionAggregation < Struct.new(
  :resource_ids,
  :function_names,
  :runtimes,
  :function_tags,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#function_tags ⇒ Array<Types::MapFilter>

The tags to include in the aggregation results.

Returns:



6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
# File 'lib/aws-sdk-inspector2/types.rb', line 6849

class LambdaFunctionAggregation < Struct.new(
  :resource_ids,
  :function_names,
  :runtimes,
  :function_tags,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#resource_ids ⇒ Array<Types::StringFilter>

The resource IDs to include in the aggregation results.

Returns:



6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
# File 'lib/aws-sdk-inspector2/types.rb', line 6849

class LambdaFunctionAggregation < Struct.new(
  :resource_ids,
  :function_names,
  :runtimes,
  :function_tags,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#runtimes ⇒ Array<Types::StringFilter>

Returns findings aggregated by Amazon Web Services Lambda function runtime environments.

Returns:



6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
# File 'lib/aws-sdk-inspector2/types.rb', line 6849

class LambdaFunctionAggregation < Struct.new(
  :resource_ids,
  :function_names,
  :runtimes,
  :function_tags,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ String

The finding severity to use for sorting the results.

Returns:

  • (String)


6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
# File 'lib/aws-sdk-inspector2/types.rb', line 6849

class LambdaFunctionAggregation < Struct.new(
  :resource_ids,
  :function_names,
  :runtimes,
  :function_tags,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#sort_order ⇒ String

The order to use for sorting the results.

Returns:

  • (String)


6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
# File 'lib/aws-sdk-inspector2/types.rb', line 6849

class LambdaFunctionAggregation < Struct.new(
  :resource_ids,
  :function_names,
  :runtimes,
  :function_tags,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end