Class: Aws::Inspector2::Types::LambdaFunctionMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

The Amazon Web Services Lambda function metadata.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#function_name ⇒ String

The name of a function.

Returns:

  • (String)


6930
6931
6932
6933
6934
6935
6936
6937
# File 'lib/aws-sdk-inspector2/types.rb', line 6930

class LambdaFunctionMetadata < Struct.new(
  :function_tags,
  :layers,
  :function_name,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end

#function_tags ⇒ Hash<String,String>

The resource tags on an Amazon Web Services Lambda function.

Returns:

  • (Hash<String,String>)


6930
6931
6932
6933
6934
6935
6936
6937
# File 'lib/aws-sdk-inspector2/types.rb', line 6930

class LambdaFunctionMetadata < Struct.new(
  :function_tags,
  :layers,
  :function_name,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end

#layers ⇒ Array<String>

The layers for an Amazon Web Services Lambda function. A Lambda function can have up to five layers.

Returns:

  • (Array<String>)


6930
6931
6932
6933
6934
6935
6936
6937
# File 'lib/aws-sdk-inspector2/types.rb', line 6930

class LambdaFunctionMetadata < Struct.new(
  :function_tags,
  :layers,
  :function_name,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end

#runtime ⇒ String

An Amazon Web Services Lambda function's runtime.

Returns:

  • (String)


6930
6931
6932
6933
6934
6935
6936
6937
# File 'lib/aws-sdk-inspector2/types.rb', line 6930

class LambdaFunctionMetadata < Struct.new(
  :function_tags,
  :layers,
  :function_name,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end