Class: Aws::Inspector2::Types::LambdaLayerAggregation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

The details that define a findings aggregation based on an Amazon Web Services Lambda function's layers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#function_names ⇒ Array<Types::StringFilter>

The names of the Amazon Web Services Lambda functions associated with the layers.

Returns:



6966
6967
6968
6969
6970
6971
6972
6973
6974
# File 'lib/aws-sdk-inspector2/types.rb', line 6966

class LambdaLayerAggregation < Struct.new(
  :function_names,
  :resource_ids,
  :layer_arns,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#layer_arns ⇒ Array<Types::StringFilter>

The Amazon Resource Name (ARN) of the Amazon Web Services Lambda function layer.

Returns:



6966
6967
6968
6969
6970
6971
6972
6973
6974
# File 'lib/aws-sdk-inspector2/types.rb', line 6966

class LambdaLayerAggregation < Struct.new(
  :function_names,
  :resource_ids,
  :layer_arns,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#resource_ids ⇒ Array<Types::StringFilter>

The resource IDs for the Amazon Web Services Lambda function layers.

Returns:



6966
6967
6968
6969
6970
6971
6972
6973
6974
# File 'lib/aws-sdk-inspector2/types.rb', line 6966

class LambdaLayerAggregation < Struct.new(
  :function_names,
  :resource_ids,
  :layer_arns,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ String

The finding severity to use for sorting the results.

Returns:

  • (String)


6966
6967
6968
6969
6970
6971
6972
6973
6974
# File 'lib/aws-sdk-inspector2/types.rb', line 6966

class LambdaLayerAggregation < Struct.new(
  :function_names,
  :resource_ids,
  :layer_arns,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#sort_order ⇒ String

The order to use for sorting the results.

Returns:

  • (String)


6966
6967
6968
6969
6970
6971
6972
6973
6974
# File 'lib/aws-sdk-inspector2/types.rb', line 6966

class LambdaLayerAggregation < Struct.new(
  :function_names,
  :resource_ids,
  :layer_arns,
  :sort_order,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end