Class: Aws::Inspector2::Types::LambdaLayerAggregationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

A response that contains the results of an Amazon Web Services Lambda function layer finding aggregation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The account ID of the Amazon Web Services Lambda function layer.

Returns:

  • (String)


7004
7005
7006
7007
7008
7009
7010
7011
7012
# File 'lib/aws-sdk-inspector2/types.rb', line 7004

class LambdaLayerAggregationResponse < Struct.new(
  :function_name,
  :resource_id,
  :layer_arn,
  :account_id,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#function_name ⇒ String

The names of the Amazon Web Services Lambda functions associated with the layers.

Returns:

  • (String)


7004
7005
7006
7007
7008
7009
7010
7011
7012
# File 'lib/aws-sdk-inspector2/types.rb', line 7004

class LambdaLayerAggregationResponse < Struct.new(
  :function_name,
  :resource_id,
  :layer_arn,
  :account_id,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#layer_arn ⇒ String

The Amazon Resource Name (ARN) of the Amazon Web Services Lambda function layer.

Returns:

  • (String)


7004
7005
7006
7007
7008
7009
7010
7011
7012
# File 'lib/aws-sdk-inspector2/types.rb', line 7004

class LambdaLayerAggregationResponse < Struct.new(
  :function_name,
  :resource_id,
  :layer_arn,
  :account_id,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#resource_id ⇒ String

The Resource ID of the Amazon Web Services Lambda function layer.

Returns:

  • (String)


7004
7005
7006
7007
7008
7009
7010
7011
7012
# File 'lib/aws-sdk-inspector2/types.rb', line 7004

class LambdaLayerAggregationResponse < Struct.new(
  :function_name,
  :resource_id,
  :layer_arn,
  :account_id,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#severity_counts ⇒ Types::SeverityCounts

An object that contains the counts of aggregated finding per severity.



7004
7005
7006
7007
7008
7009
7010
7011
7012
# File 'lib/aws-sdk-inspector2/types.rb', line 7004

class LambdaLayerAggregationResponse < Struct.new(
  :function_name,
  :resource_id,
  :layer_arn,
  :account_id,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end