Class: Aws::Inspector2::Types::LambdaVpcConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

The VPC security groups and subnets that are attached to an Amazon Web Services Lambda function. For more information, see VPC Settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#security_group_ids ⇒ Array<String>

The VPC security groups and subnets that are attached to an Amazon Web Services Lambda function. For more information, see VPC Settings.

Returns:

  • (Array<String>)


7041
7042
7043
7044
7045
7046
7047
# File 'lib/aws-sdk-inspector2/types.rb', line 7041

class LambdaVpcConfig < Struct.new(
  :subnet_ids,
  :security_group_ids,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_ids ⇒ Array<String>

A list of VPC subnet IDs.

Returns:

  • (Array<String>)


7041
7042
7043
7044
7045
7046
7047
# File 'lib/aws-sdk-inspector2/types.rb', line 7041

class LambdaVpcConfig < Struct.new(
  :subnet_ids,
  :security_group_ids,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_id ⇒ String

The ID of the VPC.

Returns:

  • (String)


7041
7042
7043
7044
7045
7046
7047
# File 'lib/aws-sdk-inspector2/types.rb', line 7041

class LambdaVpcConfig < Struct.new(
  :subnet_ids,
  :security_group_ids,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end