Class: Aws::Inspector2::Types::Member

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Details on a member account in your organization.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The Amazon Web Services account ID of the member account.

Returns:

  • (String)


8132
8133
8134
8135
8136
8137
8138
8139
# File 'lib/aws-sdk-inspector2/types.rb', line 8132

class Member < Struct.new(
  :account_id,
  :relationship_status,
  :delegated_admin_account_id,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#delegated_admin_account_id ⇒ String

The Amazon Web Services account ID of the Amazon Inspector delegated administrator for this member account.

Returns:

  • (String)


8132
8133
8134
8135
8136
8137
8138
8139
# File 'lib/aws-sdk-inspector2/types.rb', line 8132

class Member < Struct.new(
  :account_id,
  :relationship_status,
  :delegated_admin_account_id,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#relationship_status ⇒ String

The status of the member account.

Returns:

  • (String)


8132
8133
8134
8135
8136
8137
8138
8139
# File 'lib/aws-sdk-inspector2/types.rb', line 8132

class Member < Struct.new(
  :account_id,
  :relationship_status,
  :delegated_admin_account_id,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_at ⇒ Time

A timestamp showing when the status of this member was last updated.

Returns:



8132
8133
8134
8135
8136
8137
8138
8139
# File 'lib/aws-sdk-inspector2/types.rb', line 8132

class Member < Struct.new(
  :account_id,
  :relationship_status,
  :delegated_admin_account_id,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end