Class: Aws::Inspector2::Types::MemberAccountEc2DeepInspectionStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

An object that contains details about the status of Amazon Inspector deep inspection for a member account in your organization.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The unique identifier for the Amazon Web Services account of the organization member.



6855
6856
6857
6858
6859
6860
# File 'lib/aws-sdk-inspector2/types.rb', line 6855

class MemberAccountEc2DeepInspectionStatus < Struct.new(
  :account_id,
  :activate_deep_inspection)
  SENSITIVE = []
  include Aws::Structure
end

#activate_deep_inspectionBoolean

Whether Amazon Inspector deep inspection is active in the account. If TRUE Amazon Inspector deep inspection is active, if FALSE it is not active.



6855
6856
6857
6858
6859
6860
# File 'lib/aws-sdk-inspector2/types.rb', line 6855

class MemberAccountEc2DeepInspectionStatus < Struct.new(
  :account_id,
  :activate_deep_inspection)
  SENSITIVE = []
  include Aws::Structure
end