Class: Aws::Inspector2::Types::PeriodicScanConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Configuration settings for periodic scans that run on a scheduled basis.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#frequency ⇒ String

The frequency at which periodic scans are performed (such as weekly or monthly).

If you don't provide the frequencyExpression Amazon Inspector chooses day for the scan to run. If you provide the frequencyExpression, the schedule must match the specified frequency.

Returns:

  • (String)


8462
8463
8464
8465
8466
8467
# File 'lib/aws-sdk-inspector2/types.rb', line 8462

class PeriodicScanConfiguration < Struct.new(
  :frequency,
  :frequency_expression)
  SENSITIVE = []
  include Aws::Structure
end

#frequency_expression ⇒ String

The schedule expression for periodic scans, in cron format.

Returns:

  • (String)


8462
8463
8464
8465
8466
8467
# File 'lib/aws-sdk-inspector2/types.rb', line 8462

class PeriodicScanConfiguration < Struct.new(
  :frequency,
  :frequency_expression)
  SENSITIVE = []
  include Aws::Structure
end