Class: Aws::Inspector2::Types::Resource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Details about the resource involved in a finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#details ⇒ Types::ResourceDetails

An object that contains details about the resource involved in a finding.



8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
# File 'lib/aws-sdk-inspector2/types.rb', line 8850

class Resource < Struct.new(
  :type,
  :id,
  :partition,
  :region,
  :tags,
  :details,
  :provider,
  :provider_account_id,
  :provider_org_id)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the resource.

Returns:

  • (String)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
# File 'lib/aws-sdk-inspector2/types.rb', line 8850

class Resource < Struct.new(
  :type,
  :id,
  :partition,
  :region,
  :tags,
  :details,
  :provider,
  :provider_account_id,
  :provider_org_id)
  SENSITIVE = []
  include Aws::Structure
end

#partition ⇒ String

The partition of the resource.

Returns:

  • (String)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
# File 'lib/aws-sdk-inspector2/types.rb', line 8850

class Resource < Struct.new(
  :type,
  :id,
  :partition,
  :region,
  :tags,
  :details,
  :provider,
  :provider_account_id,
  :provider_org_id)
  SENSITIVE = []
  include Aws::Structure
end

#provider ⇒ String

The cloud provider of the resource.

Returns:

  • (String)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
# File 'lib/aws-sdk-inspector2/types.rb', line 8850

class Resource < Struct.new(
  :type,
  :id,
  :partition,
  :region,
  :tags,
  :details,
  :provider,
  :provider_account_id,
  :provider_org_id)
  SENSITIVE = []
  include Aws::Structure
end

#provider_account_id ⇒ String

The cloud provider account ID of the resource.

Returns:

  • (String)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
# File 'lib/aws-sdk-inspector2/types.rb', line 8850

class Resource < Struct.new(
  :type,
  :id,
  :partition,
  :region,
  :tags,
  :details,
  :provider,
  :provider_account_id,
  :provider_org_id)
  SENSITIVE = []
  include Aws::Structure
end

#provider_org_id ⇒ String

The cloud provider organization ID of the resource.

Returns:

  • (String)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
# File 'lib/aws-sdk-inspector2/types.rb', line 8850

class Resource < Struct.new(
  :type,
  :id,
  :partition,
  :region,
  :tags,
  :details,
  :provider,
  :provider_account_id,
  :provider_org_id)
  SENSITIVE = []
  include Aws::Structure
end

#region ⇒ String

The Amazon Web Services Region the impacted resource is located in.

Returns:

  • (String)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
# File 'lib/aws-sdk-inspector2/types.rb', line 8850

class Resource < Struct.new(
  :type,
  :id,
  :partition,
  :region,
  :tags,
  :details,
  :provider,
  :provider_account_id,
  :provider_org_id)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags attached to the resource.

Returns:

  • (Hash<String,String>)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
# File 'lib/aws-sdk-inspector2/types.rb', line 8850

class Resource < Struct.new(
  :type,
  :id,
  :partition,
  :region,
  :tags,
  :details,
  :provider,
  :provider_account_id,
  :provider_org_id)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of resource.

Returns:

  • (String)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
# File 'lib/aws-sdk-inspector2/types.rb', line 8850

class Resource < Struct.new(
  :type,
  :id,
  :partition,
  :region,
  :tags,
  :details,
  :provider,
  :provider_account_id,
  :provider_org_id)
  SENSITIVE = []
  include Aws::Structure
end