Class: Aws::Inspector2::Types::ResourceStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Details the status of Amazon Inspector for each resource type Amazon Inspector scans.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_repository ⇒ String

The status of Amazon Inspector scanning for code repositories.

Returns:

  • (String)


9196
9197
9198
9199
9200
9201
9202
9203
9204
# File 'lib/aws-sdk-inspector2/types.rb', line 9196

class ResourceStatus < Struct.new(
  :ec2,
  :ecr,
  :lambda,
  :lambda_code,
  :code_repository)
  SENSITIVE = []
  include Aws::Structure
end

#ec2 ⇒ String

The status of Amazon Inspector scanning for Amazon EC2 resources.

Returns:

  • (String)


9196
9197
9198
9199
9200
9201
9202
9203
9204
# File 'lib/aws-sdk-inspector2/types.rb', line 9196

class ResourceStatus < Struct.new(
  :ec2,
  :ecr,
  :lambda,
  :lambda_code,
  :code_repository)
  SENSITIVE = []
  include Aws::Structure
end

#ecr ⇒ String

The status of Amazon Inspector scanning for Amazon ECR resources.

Returns:

  • (String)


9196
9197
9198
9199
9200
9201
9202
9203
9204
# File 'lib/aws-sdk-inspector2/types.rb', line 9196

class ResourceStatus < Struct.new(
  :ec2,
  :ecr,
  :lambda,
  :lambda_code,
  :code_repository)
  SENSITIVE = []
  include Aws::Structure
end

#lambda ⇒ String

The status of Amazon Inspector scanning for Amazon Web Services Lambda function.

Returns:

  • (String)


9196
9197
9198
9199
9200
9201
9202
9203
9204
# File 'lib/aws-sdk-inspector2/types.rb', line 9196

class ResourceStatus < Struct.new(
  :ec2,
  :ecr,
  :lambda,
  :lambda_code,
  :code_repository)
  SENSITIVE = []
  include Aws::Structure
end

#lambda_code ⇒ String

The status of Amazon Inspector scanning for custom application code for Amazon Web Services Lambda functions.

Returns:

  • (String)


9196
9197
9198
9199
9200
9201
9202
9203
9204
# File 'lib/aws-sdk-inspector2/types.rb', line 9196

class ResourceStatus < Struct.new(
  :ec2,
  :ecr,
  :lambda,
  :lambda_code,
  :code_repository)
  SENSITIVE = []
  include Aws::Structure
end