Class: Aws::Inspector2::Types::ScopeConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

The scope of resources to scan for a single scanning type. Provide this as part of an AzureScopeConfigurationInput when you create or update a connector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#scope_type ⇒ String

The type of scope. Valid values are TENANT, which scans all resources in the Azure tenant, and SUBSCRIPTION, which scans only the resources in the specified Azure subscriptions.

Returns:

  • (String)


9462
9463
9464
9465
9466
9467
# File 'lib/aws-sdk-inspector2/types.rb', line 9462

class ScopeConfigurationInput < Struct.new(
  :scope_type,
  :scope_values)
  SENSITIVE = []
  include Aws::Structure
end

#scope_values ⇒ Array<String>

The list of scope values. For subscription-level scope, these are Azure subscription IDs.

Returns:

  • (Array<String>)


9462
9463
9464
9465
9466
9467
# File 'lib/aws-sdk-inspector2/types.rb', line 9462

class ScopeConfigurationInput < Struct.new(
  :scope_type,
  :scope_values)
  SENSITIVE = []
  include Aws::Structure
end