Class: Aws::Inspector2::Types::SearchVulnerabilitiesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filter_criteria ⇒ Types::SearchVulnerabilitiesFilterCriteria

The criteria used to filter the results of a vulnerability search.



9516
9517
9518
9519
9520
9521
# File 'lib/aws-sdk-inspector2/types.rb', line 9516

class SearchVulnerabilitiesRequest < Struct.new(
  :filter_criteria,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.

Returns:

  • (String)


9516
9517
9518
9519
9520
9521
# File 'lib/aws-sdk-inspector2/types.rb', line 9516

class SearchVulnerabilitiesRequest < Struct.new(
  :filter_criteria,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end