Class: Aws::Inspector2::Types::ServerlessFunction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Contains details about a serverless function involved in a finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#architectures ⇒ Array<String>

The architectures of the serverless function.

Returns:

  • (Array<String>)


9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-inspector2/types.rb', line 9640

class ServerlessFunction < Struct.new(
  :serverless_function_name,
  :runtime,
  :version,
  :code_digest,
  :last_modified_at,
  :network_id,
  :subnet_ids,
  :security_group_ids,
  :execution_role,
  :package_type,
  :architectures,
  :layers)
  SENSITIVE = []
  include Aws::Structure
end

#code_digest ⇒ String

The code digest of the serverless function.

Returns:

  • (String)


9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-inspector2/types.rb', line 9640

class ServerlessFunction < Struct.new(
  :serverless_function_name,
  :runtime,
  :version,
  :code_digest,
  :last_modified_at,
  :network_id,
  :subnet_ids,
  :security_group_ids,
  :execution_role,
  :package_type,
  :architectures,
  :layers)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role ⇒ String

The execution role of the serverless function.

Returns:

  • (String)


9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-inspector2/types.rb', line 9640

class ServerlessFunction < Struct.new(
  :serverless_function_name,
  :runtime,
  :version,
  :code_digest,
  :last_modified_at,
  :network_id,
  :subnet_ids,
  :security_group_ids,
  :execution_role,
  :package_type,
  :architectures,
  :layers)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_at ⇒ Time

The date and time the serverless function was last modified.

Returns:



9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-inspector2/types.rb', line 9640

class ServerlessFunction < Struct.new(
  :serverless_function_name,
  :runtime,
  :version,
  :code_digest,
  :last_modified_at,
  :network_id,
  :subnet_ids,
  :security_group_ids,
  :execution_role,
  :package_type,
  :architectures,
  :layers)
  SENSITIVE = []
  include Aws::Structure
end

#layers ⇒ Array<String>

The layers of the serverless function.

Returns:

  • (Array<String>)


9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-inspector2/types.rb', line 9640

class ServerlessFunction < Struct.new(
  :serverless_function_name,
  :runtime,
  :version,
  :code_digest,
  :last_modified_at,
  :network_id,
  :subnet_ids,
  :security_group_ids,
  :execution_role,
  :package_type,
  :architectures,
  :layers)
  SENSITIVE = []
  include Aws::Structure
end

#network_id ⇒ String

The network ID associated with the serverless function.

Returns:

  • (String)


9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-inspector2/types.rb', line 9640

class ServerlessFunction < Struct.new(
  :serverless_function_name,
  :runtime,
  :version,
  :code_digest,
  :last_modified_at,
  :network_id,
  :subnet_ids,
  :security_group_ids,
  :execution_role,
  :package_type,
  :architectures,
  :layers)
  SENSITIVE = []
  include Aws::Structure
end

#package_type ⇒ String

The package type of the serverless function.

Returns:

  • (String)


9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-inspector2/types.rb', line 9640

class ServerlessFunction < Struct.new(
  :serverless_function_name,
  :runtime,
  :version,
  :code_digest,
  :last_modified_at,
  :network_id,
  :subnet_ids,
  :security_group_ids,
  :execution_role,
  :package_type,
  :architectures,
  :layers)
  SENSITIVE = []
  include Aws::Structure
end

#runtime ⇒ String

The runtime of the serverless function.

Returns:

  • (String)


9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-inspector2/types.rb', line 9640

class ServerlessFunction < Struct.new(
  :serverless_function_name,
  :runtime,
  :version,
  :code_digest,
  :last_modified_at,
  :network_id,
  :subnet_ids,
  :security_group_ids,
  :execution_role,
  :package_type,
  :architectures,
  :layers)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_ids ⇒ Array<String>

The security group IDs associated with the serverless function.

Returns:

  • (Array<String>)


9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-inspector2/types.rb', line 9640

class ServerlessFunction < Struct.new(
  :serverless_function_name,
  :runtime,
  :version,
  :code_digest,
  :last_modified_at,
  :network_id,
  :subnet_ids,
  :security_group_ids,
  :execution_role,
  :package_type,
  :architectures,
  :layers)
  SENSITIVE = []
  include Aws::Structure
end

#serverless_function_name ⇒ String

The name of the serverless function.

Returns:

  • (String)


9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-inspector2/types.rb', line 9640

class ServerlessFunction < Struct.new(
  :serverless_function_name,
  :runtime,
  :version,
  :code_digest,
  :last_modified_at,
  :network_id,
  :subnet_ids,
  :security_group_ids,
  :execution_role,
  :package_type,
  :architectures,
  :layers)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_ids ⇒ Array<String>

The subnet IDs associated with the serverless function.

Returns:

  • (Array<String>)


9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-inspector2/types.rb', line 9640

class ServerlessFunction < Struct.new(
  :serverless_function_name,
  :runtime,
  :version,
  :code_digest,
  :last_modified_at,
  :network_id,
  :subnet_ids,
  :security_group_ids,
  :execution_role,
  :package_type,
  :architectures,
  :layers)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ String

The version of the serverless function.

Returns:

  • (String)


9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
# File 'lib/aws-sdk-inspector2/types.rb', line 9640

class ServerlessFunction < Struct.new(
  :serverless_function_name,
  :runtime,
  :version,
  :code_digest,
  :last_modified_at,
  :network_id,
  :subnet_ids,
  :security_group_ids,
  :execution_role,
  :package_type,
  :architectures,
  :layers)
  SENSITIVE = []
  include Aws::Structure
end