Class: Aws::Inspector2::Types::ServerlessFunctionAggregationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

A response that contains the results of a serverless function aggregation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The account ID associated with the serverless function.

Returns:

  • (String)


9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_account_id ⇒ String

The cloud account ID for the serverless function aggregation.

Returns:

  • (String)


9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_org_id ⇒ String

The cloud organization ID for the serverless function aggregation.

Returns:

  • (String)


9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_partition ⇒ String

The cloud infrastructure partition associated with this serverless function aggregation. Valid values:

  • aws – Amazon Web Services commercial Regions.

  • aws-cn – Amazon Web Services China Regions.

  • aws-us-gov – Amazon Web Services GovCloud (US) Regions.

  • AzureCloud – Azure commercial Regions.

Returns:

  • (String)


9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_provider ⇒ String

The cloud service provider associated with this serverless function aggregation. Valid values:

  • AWS – Findings from Amazon Web Services resources.

  • AZURE – Findings from Microsoft Azure resources.

Returns:

  • (String)


9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_region ⇒ String

The cloud Region associated with this serverless function aggregation. The value format depends on the cloud provider:

  • An Amazon Web Services Region, such as us-east-1.

  • An Azure region, such as eastus.

Returns:

  • (String)


9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#exploit_available_active_findings_count ⇒ Integer

The number of active findings with an exploit available for the serverless function.

Returns:

  • (Integer)


9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#fix_available_active_findings_count ⇒ Integer

The number of active findings with a fix available for the serverless function.

Returns:

  • (Integer)


9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#function_name ⇒ String

The name of the serverless function.

Returns:

  • (String)


9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_at ⇒ Time

The date and time the serverless function was last modified.

Returns:



9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#resource_id ⇒ String

The resource ID for the serverless function.

Returns:

  • (String)


9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#runtime ⇒ String

The runtime of the serverless function.

Returns:

  • (String)


9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#severity_counts ⇒ Types::SeverityCounts

An object that contains the counts of aggregated finding per severity.



9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags attached to the serverless function.

Returns:

  • (Hash<String,String>)


9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-inspector2/types.rb', line 9822

class ServerlessFunctionAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :function_name,
  :runtime,
  :tags,
  :account_id,
  :severity_counts,
  :last_modified_at,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end