Class: Aws::Inspector2::Types::ServiceQuotaExceededException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

You have exceeded your service quota. To perform the requested action, remove some of the relevant resources, or use Service Quotas to request a service quota increase.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#message ⇒ String

Returns:

  • (String)


9879
9880
9881
9882
9883
9884
# File 'lib/aws-sdk-inspector2/types.rb', line 9879

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_id ⇒ String

The ID of the resource that exceeds a service quota.

Returns:

  • (String)


9879
9880
9881
9882
9883
9884
# File 'lib/aws-sdk-inspector2/types.rb', line 9879

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id)
  SENSITIVE = []
  include Aws::Structure
end