Class: Aws::Inspector2::Types::State

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

An object that described the state of Amazon Inspector scans for an account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_code ⇒ String

The error code explaining why the account failed to enable Amazon Inspector.

Returns:

  • (String)


10026
10027
10028
10029
10030
10031
10032
# File 'lib/aws-sdk-inspector2/types.rb', line 10026

class State < Struct.new(
  :status,
  :error_code,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#error_message ⇒ String

The error message received when the account failed to enable Amazon Inspector.

Returns:

  • (String)


10026
10027
10028
10029
10030
10031
10032
# File 'lib/aws-sdk-inspector2/types.rb', line 10026

class State < Struct.new(
  :status,
  :error_code,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of Amazon Inspector for the account.

Returns:

  • (String)


10026
10027
10028
10029
10030
10031
10032
# File 'lib/aws-sdk-inspector2/types.rb', line 10026

class State < Struct.new(
  :status,
  :error_code,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end