Class: Aws::Inspector2::Types::TitleAggregationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

A response that contains details on the results of a finding aggregation by title.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The ID of the Amazon Web Services account associated with the findings.

Returns:

  • (String)


10400
10401
10402
10403
10404
10405
10406
10407
# File 'lib/aws-sdk-inspector2/types.rb', line 10400

class TitleAggregationResponse < Struct.new(
  :title,
  :vulnerability_id,
  :account_id,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#severity_counts ⇒ Types::SeverityCounts

An object that represent the count of matched findings per severity.



10400
10401
10402
10403
10404
10405
10406
10407
# File 'lib/aws-sdk-inspector2/types.rb', line 10400

class TitleAggregationResponse < Struct.new(
  :title,
  :vulnerability_id,
  :account_id,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#title ⇒ String

The title that the findings were aggregated on.

Returns:

  • (String)


10400
10401
10402
10403
10404
10405
10406
10407
# File 'lib/aws-sdk-inspector2/types.rb', line 10400

class TitleAggregationResponse < Struct.new(
  :title,
  :vulnerability_id,
  :account_id,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#vulnerability_id ⇒ String

The vulnerability ID of the finding.

Returns:

  • (String)


10400
10401
10402
10403
10404
10405
10406
10407
# File 'lib/aws-sdk-inspector2/types.rb', line 10400

class TitleAggregationResponse < Struct.new(
  :title,
  :vulnerability_id,
  :account_id,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end