Class: Aws::Inspector2::Types::UpdateCodeSecurityIntegrationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::UpdateCodeSecurityIntegrationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#integration_arn ⇒ String
The Amazon Resource Name (ARN) of the updated code security integration.
-
#status ⇒ String
The current status of the updated code security integration.
Instance Attribute Details
#integration_arn ⇒ String
The Amazon Resource Name (ARN) of the updated code security integration.
10524 10525 10526 10527 10528 10529 |
# File 'lib/aws-sdk-inspector2/types.rb', line 10524 class UpdateCodeSecurityIntegrationResponse < Struct.new( :integration_arn, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the updated code security integration.
10524 10525 10526 10527 10528 10529 |
# File 'lib/aws-sdk-inspector2/types.rb', line 10524 class UpdateCodeSecurityIntegrationResponse < Struct.new( :integration_arn, :status) SENSITIVE = [] include Aws::Structure end |