Class: Aws::Inspector2::Types::UpdateConfigurationInheritance

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

The per-scan-type inheritance reset settings for the UpdateConfiguration operation. Each member is independently optional. Including a member in this structure resets that scan type's configuration to inherit from the delegated administrator.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ec2_configuration ⇒ String

The inheritance mode for Amazon EC2 scan configuration. Set to INHERIT_FROM_ADMIN to reset the member account's Amazon EC2 scan configuration to inherit from the delegated administrator. If omitted, the member account's existing Amazon EC2 scan configuration is not changed.

Returns:

  • (String)


10583
10584
10585
10586
10587
10588
# File 'lib/aws-sdk-inspector2/types.rb', line 10583

class UpdateConfigurationInheritance < Struct.new(
  :ec2_configuration,
  :ecr_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ecr_configuration ⇒ String

The inheritance mode for Amazon ECR scan configuration. Set to INHERIT_FROM_ADMIN to reset the member account's Amazon ECR scan configuration to inherit from the delegated administrator. If omitted, the member account's existing Amazon ECR scan configuration is not changed.

Returns:

  • (String)


10583
10584
10585
10586
10587
10588
# File 'lib/aws-sdk-inspector2/types.rb', line 10583

class UpdateConfigurationInheritance < Struct.new(
  :ec2_configuration,
  :ecr_configuration)
  SENSITIVE = []
  include Aws::Structure
end