Class: Aws::Inspector2::Types::UpdateConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The 12-digit Amazon Web Services account ID of the member account whose scan configuration you want to update. When specified, you must be the delegated administrator for this member account. If not specified, the operation updates your own configuration and propagates changes to any member accounts that have not been individually configured.

Returns:

  • (String)


10621
10622
10623
10624
10625
10626
10627
10628
# File 'lib/aws-sdk-inspector2/types.rb', line 10621

class UpdateConfigurationRequest < Struct.new(
  :account_id,
  :ecr_configuration,
  :ec2_configuration,
  :update_configuration_inheritance)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_configuration ⇒ Types::Ec2Configuration

Specifies how the Amazon EC2 automated scan will be updated for your environment.



10621
10622
10623
10624
10625
10626
10627
10628
# File 'lib/aws-sdk-inspector2/types.rb', line 10621

class UpdateConfigurationRequest < Struct.new(
  :account_id,
  :ecr_configuration,
  :ec2_configuration,
  :update_configuration_inheritance)
  SENSITIVE = []
  include Aws::Structure
end

#ecr_configuration ⇒ Types::EcrConfiguration

Specifies how the ECR automated re-scan will be updated for your environment.



10621
10622
10623
10624
10625
10626
10627
10628
# File 'lib/aws-sdk-inspector2/types.rb', line 10621

class UpdateConfigurationRequest < Struct.new(
  :account_id,
  :ecr_configuration,
  :ec2_configuration,
  :update_configuration_inheritance)
  SENSITIVE = []
  include Aws::Structure
end

#update_configuration_inheritance ⇒ Types::UpdateConfigurationInheritance

Specifies which scan-type configurations to reset to the delegated administrator's inherited values for the targeted member account. Each member of this structure is independently optional. When specified, ec2Configuration and ecrConfiguration must be absent, and accountId must also be present. Only INHERIT_FROM_ADMIN is valid for each member. If not specified, the operation uses the ec2Configuration and ecrConfiguration parameters instead.



10621
10622
10623
10624
10625
10626
10627
10628
# File 'lib/aws-sdk-inspector2/types.rb', line 10621

class UpdateConfigurationRequest < Struct.new(
  :account_id,
  :ecr_configuration,
  :ec2_configuration,
  :update_configuration_inheritance)
  SENSITIVE = []
  include Aws::Structure
end