Class: Aws::Inspector2::Types::UsageTotal

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

The total of usage for an account ID.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The account ID of the account that usage data was retrieved for.

Returns:

  • (String)


10978
10979
10980
10981
10982
10983
# File 'lib/aws-sdk-inspector2/types.rb', line 10978

class UsageTotal < Struct.new(
  :account_id,
  :usage)
  SENSITIVE = []
  include Aws::Structure
end

#usage ⇒ Array<Types::Usage>

An object representing the total usage for an account.

Returns:



10978
10979
10980
10981
10982
10983
# File 'lib/aws-sdk-inspector2/types.rb', line 10978

class UsageTotal < Struct.new(
  :account_id,
  :usage)
  SENSITIVE = []
  include Aws::Structure
end