Class: Aws::Inspector2::Types::VmInstanceAggregationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

A response that contains the results of a VM instance aggregation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The account ID associated with the VM instance.

Returns:

  • (String)


11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_account_id ⇒ String

The cloud account ID for the VM instance aggregation.

Returns:

  • (String)


11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_org_id ⇒ String

The cloud organization ID for the VM instance aggregation.

Returns:

  • (String)


11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_partition ⇒ String

The cloud infrastructure partition associated with this VM instance aggregation. Valid values:

  • aws – Amazon Web Services commercial Regions.

  • aws-cn – Amazon Web Services China Regions.

  • aws-us-gov – Amazon Web Services GovCloud (US) Regions.

  • AzureCloud – Azure commercial Regions.

Returns:

  • (String)


11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_provider ⇒ String

The cloud service provider associated with this VM instance aggregation. Valid values:

  • AWS – Findings from Amazon Web Services resources.

  • AZURE – Findings from Microsoft Azure resources.

Returns:

  • (String)


11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_region ⇒ String

The cloud Region associated with this VM instance aggregation. The value format depends on the cloud provider:

  • An Amazon Web Services Region, such as us-east-1.

  • An Azure region, such as eastus.

Returns:

  • (String)


11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#exploit_available_active_findings_count ⇒ Integer

The number of active findings with an exploit available for the VM instance.

Returns:

  • (Integer)


11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#fix_available_active_findings_count ⇒ Integer

The number of active findings with a fix available for the VM instance.

Returns:

  • (Integer)


11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#network_findings ⇒ Integer

The number of network findings for the VM instance. This field applies only to Amazon Web Services resources.

Returns:

  • (Integer)


11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#operating_system ⇒ String

The operating system of the VM instance.

Returns:

  • (String)


11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#resource_id ⇒ String

The resource ID for the VM instance.

Returns:

  • (String)


11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#severity_counts ⇒ Types::SeverityCounts

An object that contains the counts of aggregated finding per severity.



11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags attached to the VM instance.

Returns:

  • (Hash<String,String>)


11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end

#vm_image_reference ⇒ String

The VM image reference for the VM instance.

Returns:

  • (String)


11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
# File 'lib/aws-sdk-inspector2/types.rb', line 11287

class VmInstanceAggregationResponse < Struct.new(
  :resource_id,
  :cloud_provider,
  :cloud_account_id,
  :cloud_partition,
  :cloud_region,
  :cloud_org_id,
  :vm_image_reference,
  :operating_system,
  :tags,
  :account_id,
  :severity_counts,
  :network_findings,
  :exploit_available_active_findings_count,
  :fix_available_active_findings_count)
  SENSITIVE = []
  include Aws::Structure
end