Class: Aws::Inspector2::Types::Vulnerability

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Contains details about a specific vulnerability Amazon Inspector can detect.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#atig_data ⇒ Types::AtigData

An object that contains information about the Amazon Web Services Threat Intel Group (ATIG) details for the vulnerability.

Returns:



11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#cisa_data ⇒ Types::CisaData

An object that contains the Cybersecurity and Infrastructure Security Agency (CISA) details for the vulnerability.

Returns:



11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#cvss2 ⇒ Types::Cvss2

An object that contains the Common Vulnerability Scoring System (CVSS) Version 2 details for the vulnerability.

Returns:



11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#cvss3 ⇒ Types::Cvss3

An object that contains the Common Vulnerability Scoring System (CVSS) Version 3 details for the vulnerability.

Returns:



11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#cvss4 ⇒ Types::Cvss4

An object that contains the Common Vulnerability Scoring System (CVSS) Version 4 details for the vulnerability.

Returns:



11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#cwes ⇒ Array<String>

The Common Weakness Enumeration (CWE) associated with the vulnerability.

Returns:

  • (Array<String>)


11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

A description of the vulnerability.

Returns:

  • (String)


11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#detection_platforms ⇒ Array<String>

Platforms that the vulnerability can be detected on.

Returns:

  • (Array<String>)


11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#epss ⇒ Types::Epss

An object that contains the Exploit Prediction Scoring System (EPSS) score for a vulnerability.

Returns:



11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#exploit_observed ⇒ Types::ExploitObserved

An object that contains details on when the exploit was observed.



11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID for the specific vulnerability.

Returns:

  • (String)


11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#reference_urls ⇒ Array<String>

Links to various resources with more information on this vulnerability.

Returns:

  • (Array<String>)


11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

A list of related vulnerabilities.

Returns:

  • (Array<String>)


11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#source ⇒ String

The source of the vulnerability information. Possible results are RHEL, AMAZON_CVE, DEBIAN or NVD.

Returns:

  • (String)


11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#source_url ⇒ String

A link to the official source material for this vulnerability.

Returns:

  • (String)


11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_created_at ⇒ Time

The date and time when the vendor created this vulnerability.

Returns:



11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_severity ⇒ String

The severity assigned by the vendor.

Returns:

  • (String)


11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_updated_at ⇒ Time

The date and time when the vendor last updated this vulnerability.

Returns:



11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
# File 'lib/aws-sdk-inspector2/types.rb', line 11422

class Vulnerability < Struct.new(
  :id,
  :cwes,
  :cisa_data,
  :source,
  :description,
  :atig_data,
  :vendor_severity,
  :cvss4,
  :cvss3,
  :related_vulnerabilities,
  :cvss2,
  :vendor_created_at,
  :vendor_updated_at,
  :source_url,
  :reference_urls,
  :exploit_observed,
  :detection_platforms,
  :epss)
  SENSITIVE = []
  include Aws::Structure
end