Class: Aws::Inspector2::Types::VulnerablePackage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-inspector2/types.rb

Overview

Information on the vulnerable package identified by a finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arch ⇒ String

The architecture of the vulnerable package.

Returns:

  • (String)


11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-inspector2/types.rb', line 11495

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation,
  :source_lambda_layer_arn)
  SENSITIVE = []
  include Aws::Structure
end

#epoch ⇒ Integer

The epoch of the vulnerable package.

Returns:

  • (Integer)


11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-inspector2/types.rb', line 11495

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation,
  :source_lambda_layer_arn)
  SENSITIVE = []
  include Aws::Structure
end

#file_path ⇒ String

The file path of the vulnerable package.

Returns:

  • (String)


11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-inspector2/types.rb', line 11495

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation,
  :source_lambda_layer_arn)
  SENSITIVE = []
  include Aws::Structure
end

#fixed_in_version ⇒ String

The version of the package that contains the vulnerability fix.

Returns:

  • (String)


11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-inspector2/types.rb', line 11495

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation,
  :source_lambda_layer_arn)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the vulnerable package.

Returns:

  • (String)


11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-inspector2/types.rb', line 11495

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation,
  :source_lambda_layer_arn)
  SENSITIVE = []
  include Aws::Structure
end

#package_manager ⇒ String

The package manager of the vulnerable package.

Returns:

  • (String)


11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-inspector2/types.rb', line 11495

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation,
  :source_lambda_layer_arn)
  SENSITIVE = []
  include Aws::Structure
end

#release ⇒ String

The release of the vulnerable package.

Returns:

  • (String)


11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-inspector2/types.rb', line 11495

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation,
  :source_lambda_layer_arn)
  SENSITIVE = []
  include Aws::Structure
end

#remediation ⇒ String

The code to run in your environment to update packages with a fix available.

Returns:

  • (String)


11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-inspector2/types.rb', line 11495

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation,
  :source_lambda_layer_arn)
  SENSITIVE = []
  include Aws::Structure
end

#source_lambda_layer_arn ⇒ String

The Amazon Resource Number (ARN) of the Amazon Web Services Lambda function affected by a finding.

Returns:

  • (String)


11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-inspector2/types.rb', line 11495

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation,
  :source_lambda_layer_arn)
  SENSITIVE = []
  include Aws::Structure
end

#source_layer_hash ⇒ String

The source layer hash of the vulnerable package.

Returns:

  • (String)


11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-inspector2/types.rb', line 11495

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation,
  :source_lambda_layer_arn)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ String

The version of the vulnerable package.

Returns:

  • (String)


11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-inspector2/types.rb', line 11495

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation,
  :source_lambda_layer_arn)
  SENSITIVE = []
  include Aws::Structure
end