Class: Aws::Inspector2::Waiters::ConnectorDeleted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-inspector2/waiters.rb,
sig/waiters.rbs

Overview

Wait until a connector is no longer returned by ListConnectors. Caller MUST filter ListConnectors by the specific connector ARN; success is reached when the filtered result returns zero items. Failure when the deletion terminally fails (FAILED_TO_DELETE).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ConnectorDeleted

Returns a new instance of ConnectorDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 5
  • :delay (Integer) — default: 30
  • :before_attempt (Proc)
  • :before_wait (Proc)


138
139
# File 'lib/aws-sdk-inspector2/waiters.rb', line 138

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



170
171
172
# File 'lib/aws-sdk-inspector2/waiters.rb', line 170

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::ListConnectorsResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :max_results (Integer)

    The maximum number of results to return in a single call. To retrieve the remaining results, make another request with the nextToken value returned from this request.

  • :next_token (String)

    A token to use for paginating results. Set this value to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

  • :filter_criteria (Types::ConnectorFilterCriteria)

    The filter criteria to apply to the list of connectors.

Returns:



165
# File 'lib/aws-sdk-inspector2/waiters.rb', line 165

def wait: (