Class: Aws::Inspector2::Types::AzureProviderDetailCreate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::AzureProviderDetailCreate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
The Azure-specific configuration details for creating a connector, including the Amazon Web Services Config connector association, scan scope, and regions to scan.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_install_vm_scanner ⇒ Boolean
Specifies whether to automatically install the VM scanner on connected Azure resources.
-
#aws_config_connector_arn ⇒ String
The ARN of the Amazon Web Services Config connector to associate with this connector.
-
#azure_regions ⇒ Array<String>
The Azure regions to scan.
-
#scope_configuration ⇒ Types::AzureScopeConfigurationInput
The scope configuration that defines which Azure resources to scan.
Instance Attribute Details
#auto_install_vm_scanner ⇒ Boolean
Specifies whether to automatically install the VM scanner on
connected Azure resources. Defaults to true.
1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/aws-sdk-inspector2/types.rb', line 1010 class AzureProviderDetailCreate < Struct.new( :aws_config_connector_arn, :scope_configuration, :azure_regions, :auto_install_vm_scanner) SENSITIVE = [] include Aws::Structure end |
#aws_config_connector_arn ⇒ String
The ARN of the Amazon Web Services Config connector to associate with this connector.
1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/aws-sdk-inspector2/types.rb', line 1010 class AzureProviderDetailCreate < Struct.new( :aws_config_connector_arn, :scope_configuration, :azure_regions, :auto_install_vm_scanner) SENSITIVE = [] include Aws::Structure end |
#azure_regions ⇒ Array<String>
The Azure regions to scan.
1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/aws-sdk-inspector2/types.rb', line 1010 class AzureProviderDetailCreate < Struct.new( :aws_config_connector_arn, :scope_configuration, :azure_regions, :auto_install_vm_scanner) SENSITIVE = [] include Aws::Structure end |
#scope_configuration ⇒ Types::AzureScopeConfigurationInput
The scope configuration that defines which Azure resources to scan.
1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/aws-sdk-inspector2/types.rb', line 1010 class AzureProviderDetailCreate < Struct.new( :aws_config_connector_arn, :scope_configuration, :azure_regions, :auto_install_vm_scanner) SENSITIVE = [] include Aws::Structure end |