Class: Aws::Inspector2::Types::AzureProviderDetailUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::AzureProviderDetailUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
The Azure-specific configuration details for updating a connector, including the scan scope and regions to scan.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_install_vm_scanner ⇒ Boolean
Specifies whether to automatically install the VM scanner on connected Azure resources.
-
#azure_regions ⇒ Array<String>
The updated Azure regions to scan.
-
#scope_configuration ⇒ Types::AzureScopeConfigurationInput
The updated scope configuration that defines which Azure resources to scan.
Instance Attribute Details
#auto_install_vm_scanner ⇒ Boolean
Specifies whether to automatically install the VM scanner on connected Azure resources.
1038 1039 1040 1041 1042 1043 1044 |
# File 'lib/aws-sdk-inspector2/types.rb', line 1038 class AzureProviderDetailUpdate < Struct.new( :azure_regions, :scope_configuration, :auto_install_vm_scanner) SENSITIVE = [] include Aws::Structure end |
#azure_regions ⇒ Array<String>
The updated Azure regions to scan.
1038 1039 1040 1041 1042 1043 1044 |
# File 'lib/aws-sdk-inspector2/types.rb', line 1038 class AzureProviderDetailUpdate < Struct.new( :azure_regions, :scope_configuration, :auto_install_vm_scanner) SENSITIVE = [] include Aws::Structure end |
#scope_configuration ⇒ Types::AzureScopeConfigurationInput
The updated scope configuration that defines which Azure resources to scan.
1038 1039 1040 1041 1042 1043 1044 |
# File 'lib/aws-sdk-inspector2/types.rb', line 1038 class AzureProviderDetailUpdate < Struct.new( :azure_regions, :scope_configuration, :auto_install_vm_scanner) SENSITIVE = [] include Aws::Structure end |