Class: Aws::Inspector2::Types::Ec2Configuration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::Ec2Configuration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
Enables agent-based scanning, which scans instances that are not managed by SSM.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activate_vm_scanner ⇒ Boolean
Whether to activate Amazon Inspector VM scanner for Amazon EC2 scanning.
-
#scan_mode ⇒ String
The scan method that is applied to the instance.
Instance Attribute Details
#activate_vm_scanner ⇒ Boolean
Whether to activate Amazon Inspector VM scanner for Amazon EC2 scanning.
4553 4554 4555 4556 4557 4558 |
# File 'lib/aws-sdk-inspector2/types.rb', line 4553 class Ec2Configuration < Struct.new( :scan_mode, :activate_vm_scanner) SENSITIVE = [] include Aws::Structure end |
#scan_mode ⇒ String
The scan method that is applied to the instance.
4553 4554 4555 4556 4557 4558 |
# File 'lib/aws-sdk-inspector2/types.rb', line 4553 class Ec2Configuration < Struct.new( :scan_mode, :activate_vm_scanner) SENSITIVE = [] include Aws::Structure end |