Class: Aws::Inspector2::Types::EcrRescanDurationState
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::EcrRescanDurationState
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
Details about the state of your ECR re-scan duration settings. The ECR
re-scan duration defines how long an ECR image will be actively
scanned by Amazon Inspector. When the number of days since an image
was last pushed exceeds the duration configured for image pull date,
and the duration configured for image pull date, the monitoring state
of that image becomes inactive and all associated findings are
scheduled for closure.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#pull_date_rescan_duration ⇒ String
The rescan duration configured for image pull date.
-
#pull_date_rescan_mode ⇒ String
The pull date for the re-scan mode.
-
#rescan_duration ⇒ String
The rescan duration configured for image push date.
-
#status ⇒ String
The status of changes to the ECR automated re-scan duration.
-
#updated_at ⇒ Time
A timestamp representing when the last time the ECR scan duration setting was changed.
Instance Attribute Details
#pull_date_rescan_duration ⇒ String
The rescan duration configured for image pull date.
4836 4837 4838 4839 4840 4841 4842 4843 4844 |
# File 'lib/aws-sdk-inspector2/types.rb', line 4836 class EcrRescanDurationState < Struct.new( :rescan_duration, :status, :updated_at, :pull_date_rescan_duration, :pull_date_rescan_mode) SENSITIVE = [] include Aws::Structure end |
#pull_date_rescan_mode ⇒ String
The pull date for the re-scan mode.
4836 4837 4838 4839 4840 4841 4842 4843 4844 |
# File 'lib/aws-sdk-inspector2/types.rb', line 4836 class EcrRescanDurationState < Struct.new( :rescan_duration, :status, :updated_at, :pull_date_rescan_duration, :pull_date_rescan_mode) SENSITIVE = [] include Aws::Structure end |
#rescan_duration ⇒ String
The rescan duration configured for image push date.
4836 4837 4838 4839 4840 4841 4842 4843 4844 |
# File 'lib/aws-sdk-inspector2/types.rb', line 4836 class EcrRescanDurationState < Struct.new( :rescan_duration, :status, :updated_at, :pull_date_rescan_duration, :pull_date_rescan_mode) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of changes to the ECR automated re-scan duration.
4836 4837 4838 4839 4840 4841 4842 4843 4844 |
# File 'lib/aws-sdk-inspector2/types.rb', line 4836 class EcrRescanDurationState < Struct.new( :rescan_duration, :status, :updated_at, :pull_date_rescan_duration, :pull_date_rescan_mode) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
A timestamp representing when the last time the ECR scan duration setting was changed.
4836 4837 4838 4839 4840 4841 4842 4843 4844 |
# File 'lib/aws-sdk-inspector2/types.rb', line 4836 class EcrRescanDurationState < Struct.new( :rescan_duration, :status, :updated_at, :pull_date_rescan_duration, :pull_date_rescan_mode) SENSITIVE = [] include Aws::Structure end |