Class: Aws::Inspector2::Types::FindingTypeAggregationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::FindingTypeAggregationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
A response that contains the results of a finding type aggregation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the Amazon Web Services account associated with the findings.
-
#cloud_account_id ⇒ String
The cloud account ID for the finding type aggregation.
-
#cloud_org_id ⇒ String
The cloud organization ID for the finding type aggregation.
-
#cloud_partition ⇒ String
The cloud infrastructure partition associated with this finding type aggregation.
-
#cloud_provider ⇒ String
The cloud service provider associated with this finding type aggregation.
-
#cloud_region ⇒ String
The cloud Region associated with this finding type aggregation.
-
#exploit_available_count ⇒ Integer
The number of findings that have an exploit available.
-
#fix_available_count ⇒ Integer
Details about the number of fixes.
-
#severity_counts ⇒ Types::SeverityCounts
The value to sort results by.
Instance Attribute Details
#account_id ⇒ String
The ID of the Amazon Web Services account associated with the findings.
5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5870 class FindingTypeAggregationResponse < Struct.new( :account_id, :severity_counts, :exploit_available_count, :fix_available_count, :cloud_provider, :cloud_account_id, :cloud_org_id, :cloud_region, :cloud_partition) SENSITIVE = [] include Aws::Structure end |
#cloud_account_id ⇒ String
The cloud account ID for the finding type aggregation.
5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5870 class FindingTypeAggregationResponse < Struct.new( :account_id, :severity_counts, :exploit_available_count, :fix_available_count, :cloud_provider, :cloud_account_id, :cloud_org_id, :cloud_region, :cloud_partition) SENSITIVE = [] include Aws::Structure end |
#cloud_org_id ⇒ String
The cloud organization ID for the finding type aggregation.
5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5870 class FindingTypeAggregationResponse < Struct.new( :account_id, :severity_counts, :exploit_available_count, :fix_available_count, :cloud_provider, :cloud_account_id, :cloud_org_id, :cloud_region, :cloud_partition) SENSITIVE = [] include Aws::Structure end |
#cloud_partition ⇒ String
The cloud infrastructure partition associated with this finding type aggregation. Valid values:
-
aws– Amazon Web Services commercial Regions. -
aws-cn– Amazon Web Services China Regions. -
aws-us-gov– Amazon Web Services GovCloud (US) Regions. -
AzureCloud– Azure commercial Regions.
5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5870 class FindingTypeAggregationResponse < Struct.new( :account_id, :severity_counts, :exploit_available_count, :fix_available_count, :cloud_provider, :cloud_account_id, :cloud_org_id, :cloud_region, :cloud_partition) SENSITIVE = [] include Aws::Structure end |
#cloud_provider ⇒ String
The cloud service provider associated with this finding type aggregation. Valid values:
-
AWS– Findings from Amazon Web Services resources. -
AZURE– Findings from Microsoft Azure resources.
5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5870 class FindingTypeAggregationResponse < Struct.new( :account_id, :severity_counts, :exploit_available_count, :fix_available_count, :cloud_provider, :cloud_account_id, :cloud_org_id, :cloud_region, :cloud_partition) SENSITIVE = [] include Aws::Structure end |
#cloud_region ⇒ String
The cloud Region associated with this finding type aggregation. The value format depends on the cloud provider:
-
An Amazon Web Services Region, such as
us-east-1. -
An Azure region, such as
eastus.
5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5870 class FindingTypeAggregationResponse < Struct.new( :account_id, :severity_counts, :exploit_available_count, :fix_available_count, :cloud_provider, :cloud_account_id, :cloud_org_id, :cloud_region, :cloud_partition) SENSITIVE = [] include Aws::Structure end |
#exploit_available_count ⇒ Integer
The number of findings that have an exploit available.
5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5870 class FindingTypeAggregationResponse < Struct.new( :account_id, :severity_counts, :exploit_available_count, :fix_available_count, :cloud_provider, :cloud_account_id, :cloud_org_id, :cloud_region, :cloud_partition) SENSITIVE = [] include Aws::Structure end |
#fix_available_count ⇒ Integer
Details about the number of fixes.
5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5870 class FindingTypeAggregationResponse < Struct.new( :account_id, :severity_counts, :exploit_available_count, :fix_available_count, :cloud_provider, :cloud_account_id, :cloud_org_id, :cloud_region, :cloud_partition) SENSITIVE = [] include Aws::Structure end |
#severity_counts ⇒ Types::SeverityCounts
The value to sort results by.
5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 |
# File 'lib/aws-sdk-inspector2/types.rb', line 5870 class FindingTypeAggregationResponse < Struct.new( :account_id, :severity_counts, :exploit_available_count, :fix_available_count, :cloud_provider, :cloud_account_id, :cloud_org_id, :cloud_region, :cloud_partition) SENSITIVE = [] include Aws::Structure end |