Class: Aws::Inspector2::Types::GetCodeSecurityScanResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::GetCodeSecurityScanResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account ID associated with the scan.
-
#created_at ⇒ Time
The timestamp when the scan was created.
-
#last_commit_id ⇒ String
The identifier of the last commit that was scanned.
-
#resource ⇒ Types::CodeSecurityResource
The resource identifier for the code repository that was scanned.
-
#scan_id ⇒ String
The unique identifier of the scan.
-
#status ⇒ String
The current status of the scan.
-
#status_reason ⇒ String
The reason for the current status of the scan.
-
#updated_at ⇒ Time
The timestamp when the scan was last updated.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account ID associated with the scan.
6305 6306 6307 6308 6309 6310 6311 6312 6313 6314 6315 6316 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6305 class GetCodeSecurityScanResponse < Struct.new( :scan_id, :resource, :account_id, :status, :status_reason, :created_at, :updated_at, :last_commit_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the scan was created.
6305 6306 6307 6308 6309 6310 6311 6312 6313 6314 6315 6316 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6305 class GetCodeSecurityScanResponse < Struct.new( :scan_id, :resource, :account_id, :status, :status_reason, :created_at, :updated_at, :last_commit_id) SENSITIVE = [] include Aws::Structure end |
#last_commit_id ⇒ String
The identifier of the last commit that was scanned. This is only returned if the scan was successful or skipped.
6305 6306 6307 6308 6309 6310 6311 6312 6313 6314 6315 6316 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6305 class GetCodeSecurityScanResponse < Struct.new( :scan_id, :resource, :account_id, :status, :status_reason, :created_at, :updated_at, :last_commit_id) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ Types::CodeSecurityResource
The resource identifier for the code repository that was scanned.
6305 6306 6307 6308 6309 6310 6311 6312 6313 6314 6315 6316 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6305 class GetCodeSecurityScanResponse < Struct.new( :scan_id, :resource, :account_id, :status, :status_reason, :created_at, :updated_at, :last_commit_id) SENSITIVE = [] include Aws::Structure end |
#scan_id ⇒ String
The unique identifier of the scan.
6305 6306 6307 6308 6309 6310 6311 6312 6313 6314 6315 6316 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6305 class GetCodeSecurityScanResponse < Struct.new( :scan_id, :resource, :account_id, :status, :status_reason, :created_at, :updated_at, :last_commit_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the scan.
6305 6306 6307 6308 6309 6310 6311 6312 6313 6314 6315 6316 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6305 class GetCodeSecurityScanResponse < Struct.new( :scan_id, :resource, :account_id, :status, :status_reason, :created_at, :updated_at, :last_commit_id) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
The reason for the current status of the scan.
6305 6306 6307 6308 6309 6310 6311 6312 6313 6314 6315 6316 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6305 class GetCodeSecurityScanResponse < Struct.new( :scan_id, :resource, :account_id, :status, :status_reason, :created_at, :updated_at, :last_commit_id) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the scan was last updated.
6305 6306 6307 6308 6309 6310 6311 6312 6313 6314 6315 6316 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6305 class GetCodeSecurityScanResponse < Struct.new( :scan_id, :resource, :account_id, :status, :status_reason, :created_at, :updated_at, :last_commit_id) SENSITIVE = [] include Aws::Structure end |