Class: Aws::Inspector2::Types::Image
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::Image
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
Contains details about a container image involved in a finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture of the container image.
-
#author ⇒ String
The author of the container image.
-
#image_digest ⇒ String
The image digest of the container image.
-
#image_tags ⇒ Array<String>
The image tags attached to the container image.
-
#in_use_count ⇒ Integer
The number of times the container image is in use.
-
#last_in_use_at ⇒ Time
The last time the container image was in use.
-
#platform ⇒ String
The platform of the container image.
-
#pushed_at ⇒ Time
The date and time the container image was pushed.
-
#registry ⇒ String
The registry for the container image.
-
#repository_name ⇒ String
The name of the repository the container image resides in.
Instance Attribute Details
#architecture ⇒ String
The architecture of the container image.
6610 6611 6612 6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6610 class Image < Struct.new( :repository_name, :registry, :image_tags, :image_digest, :pushed_at, :architecture, :author, :in_use_count, :last_in_use_at, :platform) SENSITIVE = [] include Aws::Structure end |
#author ⇒ String
The author of the container image.
6610 6611 6612 6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6610 class Image < Struct.new( :repository_name, :registry, :image_tags, :image_digest, :pushed_at, :architecture, :author, :in_use_count, :last_in_use_at, :platform) SENSITIVE = [] include Aws::Structure end |
#image_digest ⇒ String
The image digest of the container image.
6610 6611 6612 6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6610 class Image < Struct.new( :repository_name, :registry, :image_tags, :image_digest, :pushed_at, :architecture, :author, :in_use_count, :last_in_use_at, :platform) SENSITIVE = [] include Aws::Structure end |
#image_tags ⇒ Array<String>
The image tags attached to the container image.
6610 6611 6612 6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6610 class Image < Struct.new( :repository_name, :registry, :image_tags, :image_digest, :pushed_at, :architecture, :author, :in_use_count, :last_in_use_at, :platform) SENSITIVE = [] include Aws::Structure end |
#in_use_count ⇒ Integer
The number of times the container image is in use.
6610 6611 6612 6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6610 class Image < Struct.new( :repository_name, :registry, :image_tags, :image_digest, :pushed_at, :architecture, :author, :in_use_count, :last_in_use_at, :platform) SENSITIVE = [] include Aws::Structure end |
#last_in_use_at ⇒ Time
The last time the container image was in use.
6610 6611 6612 6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6610 class Image < Struct.new( :repository_name, :registry, :image_tags, :image_digest, :pushed_at, :architecture, :author, :in_use_count, :last_in_use_at, :platform) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The platform of the container image.
6610 6611 6612 6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6610 class Image < Struct.new( :repository_name, :registry, :image_tags, :image_digest, :pushed_at, :architecture, :author, :in_use_count, :last_in_use_at, :platform) SENSITIVE = [] include Aws::Structure end |
#pushed_at ⇒ Time
The date and time the container image was pushed.
6610 6611 6612 6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6610 class Image < Struct.new( :repository_name, :registry, :image_tags, :image_digest, :pushed_at, :architecture, :author, :in_use_count, :last_in_use_at, :platform) SENSITIVE = [] include Aws::Structure end |
#registry ⇒ String
The registry for the container image.
6610 6611 6612 6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6610 class Image < Struct.new( :repository_name, :registry, :image_tags, :image_digest, :pushed_at, :architecture, :author, :in_use_count, :last_in_use_at, :platform) SENSITIVE = [] include Aws::Structure end |
#repository_name ⇒ String
The name of the repository the container image resides in.
6610 6611 6612 6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-inspector2/types.rb', line 6610 class Image < Struct.new( :repository_name, :registry, :image_tags, :image_digest, :pushed_at, :architecture, :author, :in_use_count, :last_in_use_at, :platform) SENSITIVE = [] include Aws::Structure end |