Class: Aws::Inspector2::Types::ScopeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::ScopeConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
The scope of resources that Amazon Inspector scans for a single scanning type, including the scope level, the targeted resources, and the current state.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#scope_type ⇒ String
The type of scope.
-
#scope_values ⇒ Array<String>
The list of scope values.
-
#state ⇒ String
The current state of the scope configuration.
-
#state_reason ⇒ String
The reason for the current state of the scope configuration.
Instance Attribute Details
#scope_type ⇒ String
The type of scope. Valid values are TENANT, which scans all
resources in the Azure tenant, and SUBSCRIPTION, which scans only
the resources in the specified Azure subscriptions.
9436 9437 9438 9439 9440 9441 9442 9443 |
# File 'lib/aws-sdk-inspector2/types.rb', line 9436 class ScopeConfiguration < Struct.new( :scope_type, :scope_values, :state, :state_reason) SENSITIVE = [] include Aws::Structure end |
#scope_values ⇒ Array<String>
The list of scope values. For subscription-level scope, these are Azure subscription IDs.
9436 9437 9438 9439 9440 9441 9442 9443 |
# File 'lib/aws-sdk-inspector2/types.rb', line 9436 class ScopeConfiguration < Struct.new( :scope_type, :scope_values, :state, :state_reason) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the scope configuration.
9436 9437 9438 9439 9440 9441 9442 9443 |
# File 'lib/aws-sdk-inspector2/types.rb', line 9436 class ScopeConfiguration < Struct.new( :scope_type, :scope_values, :state, :state_reason) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
The reason for the current state of the scope configuration.
9436 9437 9438 9439 9440 9441 9442 9443 |
# File 'lib/aws-sdk-inspector2/types.rb', line 9436 class ScopeConfiguration < Struct.new( :scope_type, :scope_values, :state, :state_reason) SENSITIVE = [] include Aws::Structure end |