Class: Aws::Inspector2::Types::ScopeSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::ScopeSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
Defines the scope of repositories to be included in code security scans.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#project_selection_scope ⇒ String
The scope of projects to be selected for scanning within the integrated repositories.
Instance Attribute Details
#project_selection_scope ⇒ String
The scope of projects to be selected for scanning within the
integrated repositories. Setting the value to ALL applies the
scope settings to all existing and future projects imported into
Amazon Inspector.
9481 9482 9483 9484 9485 |
# File 'lib/aws-sdk-inspector2/types.rb', line 9481 class ScopeSettings < Struct.new( :project_selection_scope) SENSITIVE = [] include Aws::Structure end |