Class: Aws::Inspector2::Types::StartCodeSecurityScanRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Inspector2::Types::StartCodeSecurityScanRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-inspector2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#resource ⇒ Types::CodeSecurityResource
The resource identifier for the code repository to scan.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
9983 9984 9985 9986 9987 9988 |
# File 'lib/aws-sdk-inspector2/types.rb', line 9983 class StartCodeSecurityScanRequest < Struct.new( :client_token, :resource) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ Types::CodeSecurityResource
The resource identifier for the code repository to scan.
9983 9984 9985 9986 9987 9988 |
# File 'lib/aws-sdk-inspector2/types.rb', line 9983 class StartCodeSecurityScanRequest < Struct.new( :client_token, :resource) SENSITIVE = [] include Aws::Structure end |