Class: Aws::Inspector2::Waiters::ConnectorDeleted
- Inherits:
-
Object
- Object
- Aws::Inspector2::Waiters::ConnectorDeleted
- Defined in:
- lib/aws-sdk-inspector2/waiters.rb,
sig/waiters.rbs
Overview
Wait until a connector is no longer returned by ListConnectors. Caller MUST filter ListConnectors by the specific connector ARN; success is reached when the filtered result returns zero items. Failure when the deletion terminally fails (FAILED_TO_DELETE).
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ConnectorDeleted
constructor
A new instance of ConnectorDeleted.
-
#wait(params = {}) ⇒ Types::ListConnectorsResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ConnectorDeleted
Returns a new instance of ConnectorDeleted.
138 139 |
# File 'lib/aws-sdk-inspector2/waiters.rb', line 138
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
170 171 172 |
# File 'lib/aws-sdk-inspector2/waiters.rb', line 170 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::ListConnectorsResponse
Returns a response object which responds to the following methods:
- #items => Array<Types::Connector>
- #next_token => String
165 |
# File 'lib/aws-sdk-inspector2/waiters.rb', line 165
def wait: (
|